@@ -105,7 +105,7 @@ class FullyPackedLoop(Element):
     A fully packed loop is a collection of non-intersecting lattice paths on a square
     grid such that every vertex is part of some path, and the paths are either closed
     internal loops or have endpoints corresponding to alternate points on the
-    boundary [Propp2001]_. They are known to be in bijection with alternating sign
+    boundary [Pro2001]_. They are known to be in bijection with alternating sign
     matrices.
 
     .. SEEALSO::
@@ -343,147 +343,140 @@ class FullyPackedLoop(Element):
         ....:     PerfectMatching(rotated_ncp)
         True
 
-    More examples::
+    More examples:
 
-        We can initiate a fully packed loop using an alternating sign matrix::
+    We can initiate a fully packed loop using an alternating sign matrix::
 
-            sage: A = AlternatingSignMatrix([[0, 0, 1], [0, 1, 0], [1, 0, 0]])
-            sage: fpl = FullyPackedLoop(A)
-            sage: fpl
-                |         |
-                |         |
-                + -- +    +
-                     |    |
-                     |    |
-             -- +    +    + --
-                |    |
-                |    |
-                +    + -- +
-                |         |
-                |         |
-            sage: FullyPackedLoops(3)(A) == fpl
-            True
+        sage: A = AlternatingSignMatrix([[0, 0, 1], [0, 1, 0], [1, 0, 0]])
+        sage: fpl = FullyPackedLoop(A)
+        sage: fpl
+            |         |
+            |         |
+            + -- +    +
+                 |    |
+                 |    |
+         -- +    +    + --
+            |    |
+            |    |
+            +    + -- +
+            |         |
+            |         |
+        sage: FullyPackedLoops(3)(A) == fpl
+        True
 
-        We can also input a matrix::
+    We can also input a matrix::
 
-            sage: FullyPackedLoop([[0, 0, 1], [0, 1, 0], [1, 0, 0]])
-                |         |
-                |         |
-                + -- +    +
-                     |    |
-                     |    |
-             -- +    +    + --
-                |    |
-                |    |
-                +    + -- +
-                |         |
-                |         |
-            sage: FullyPackedLoop([[0, 0, 1], [0, 1, 0], [1, 0, 0]]) ==\
-            ....: FullyPackedLoops(3)([[0, 0, 1], [0, 1, 0], [1, 0, 0]])
-            True
+        sage: FullyPackedLoop([[0, 0, 1], [0, 1, 0], [1, 0, 0]])
+            |         |
+            |         |
+            + -- +    +
+                 |    |
+                 |    |
+         -- +    +    + --
+            |    |
+            |    |
+            +    + -- +
+            |         |
+            |         |
+        sage: FullyPackedLoop([[0, 0, 1], [0, 1, 0], [1, 0, 0]]) ==\
+        ....: FullyPackedLoops(3)([[0, 0, 1], [0, 1, 0], [1, 0, 0]])
+        True
 
-        Otherwise we initiate a fully packed loop using a six vertex model::
+    Otherwise we initiate a fully packed loop using a six vertex model::
 
-            sage: S = SixVertexModel(3, boundary_conditions='ice').from_alternating_sign_matrix(A)
-            sage: fpl = FullyPackedLoop(S)
-            sage: fpl
-                |         |
-                |         |
-                + -- +    +
-                     |    |
-                     |    |
-             -- +    +    + --
-                |    |
-                |    |
-                +    + -- +
-                |         |
-                |         |
+        sage: S = SixVertexModel(3, boundary_conditions='ice').from_alternating_sign_matrix(A)
+        sage: fpl = FullyPackedLoop(S)
+        sage: fpl
+            |         |
+            |         |
+            + -- +    +
+                 |    |
+                 |    |
+         -- +    +    + --
+            |    |
+            |    |
+            +    + -- +
+            |         |
+            |         |
 
-            sage: FullyPackedLoops(3)(S) == FullyPackedLoop(S)
-            True
+        sage: FullyPackedLoops(3)(S) == FullyPackedLoop(S)
+        True
 
-            sage: fpl.six_vertex_model().to_alternating_sign_matrix()
-            [0 0 1]
-            [0 1 0]
-            [1 0 0]
+        sage: fpl.six_vertex_model().to_alternating_sign_matrix()
+        [0 0 1]
+        [0 1 0]
+        [1 0 0]
 
-        We can also input the matrix associated to a six vertex model::
+    We can also input the matrix associated to a six vertex model::
 
-            sage: SixVertexModel(2)([[3,1],[5,3]])
-                ^    ^
-                |    |
-            --> # <- # <--
-                |    ^
-                V    |
-            --> # -> # <--
-                |    |
-                V    V
+        sage: SixVertexModel(2)([[3,1],[5,3]])
+            ^    ^
+            |    |
+        --> # <- # <--
+            |    ^
+            V    |
+        --> # -> # <--
+            |    |
+            V    V
 
-            sage: FullyPackedLoop([[3,1],[5,3]])
-                |
-                |
-                +    + --
-                |    |
-                |    |
-             -- +    +
-                     |
-                     |
+        sage: FullyPackedLoop([[3,1],[5,3]])
+            |
+            |
+            +    + --
+            |    |
+            |    |
+         -- +    +
+                 |
+                 |
 
-            sage: FullyPackedLoops(2)([[3,1],[5,3]]) == FullyPackedLoop([[3,1],[5,3]])
-            True
+        sage: FullyPackedLoops(2)([[3,1],[5,3]]) == FullyPackedLoop([[3,1],[5,3]])
+        True
 
-        Note that the matrix corresponding to a six vertex model without
-        the ice boundary condition is not allowed::
+    Note that the matrix corresponding to a six vertex model without
+    the ice boundary condition is not allowed::
 
-            sage: SixVertexModel(2)([[3,1],[5,5]])
-                ^    ^
-                |    |
-            --> # <- # <--
-                |    ^
-                V    V
-            --> # -> # -->
-                |    |
-                V    V
+        sage: SixVertexModel(2)([[3,1],[5,5]])
+            ^    ^
+            |    |
+        --> # <- # <--
+            |    ^
+            V    V
+        --> # -> # -->
+            |    |
+            V    V
 
-            sage: FullyPackedLoop([[3,1],[5,5]])
-            Traceback (most recent call last):
-            ...
-            ValueError: invalid alternating sign matrix
+        sage: FullyPackedLoop([[3,1],[5,5]])
+        Traceback (most recent call last):
+        ...
+        ValueError: invalid alternating sign matrix
 
-            sage: FullyPackedLoops(2)([[3,1],[5,5]])
-            Traceback (most recent call last):
-            ...
-            ValueError: invalid alternating sign matrix
+        sage: FullyPackedLoops(2)([[3,1],[5,5]])
+        Traceback (most recent call last):
+        ...
+        ValueError: invalid alternating sign matrix
 
-        Note that if anything else is used to generate the fully packed loop an error will occur::
+    Note that if anything else is used to generate the fully packed loop an error will occur::
 
-            sage: fpl = FullyPackedLoop(5)
-            Traceback (most recent call last):
-            ...
-            ValueError: invalid alternating sign matrix
+        sage: fpl = FullyPackedLoop(5)
+        Traceback (most recent call last):
+        ...
+        ValueError: invalid alternating sign matrix
 
-            sage: fpl = FullyPackedLoop((1, 2, 3))
-            Traceback (most recent call last):
-            ...
-            ValueError: The alternating sign matrices must be square
+        sage: fpl = FullyPackedLoop((1, 2, 3))
+        Traceback (most recent call last):
+        ...
+        ValueError: The alternating sign matrices must be square
 
-            sage: SVM = SixVertexModel(3)[0]
-            sage: FullyPackedLoop(SVM)
-            Traceback (most recent call last):
-            ...
-            ValueError: invalid alternating sign matrix
+        sage: SVM = SixVertexModel(3)[0]
+        sage: FullyPackedLoop(SVM)
+        Traceback (most recent call last):
+        ...
+        ValueError: invalid alternating sign matrix
 
     REFERENCES:
 
-    .. [Propp2001] James Propp.
-       *The Many Faces of Alternating Sign Matrices*,
-       Discrete Mathematics and Theoretical Computer Science 43 (2001): 58
-       :arxiv:`math/0208125`
-
-    .. [Striker2015] Jessica Striker.
-       *The toggle group, homomesy, and the Razumov-Stroganov correspondence*,
-       Electron. J. Combin. 22 (2015) no. 2
-       :arxiv:`1503.08898`
+    - [Pro2001]_
+    - [Str2015]_
     """
     @staticmethod
     def __classcall_private__(cls, generator):
@@ -942,14 +935,9 @@ class FullyPackedLoop(Element):
         Return the fully packed loop obtained by applying gyration
         to the alternating sign matrix in bijection with ``self``.
 
-        Gyration was first defined in [Wieland00]_ as an action on
+        Gyration was first defined in [Wie2000]_ as an action on
         fully-packed loops.
 
-        REFERENCES:
-
-        .. [Wieland00] \B. Wieland. *A large dihedral symmetry of the set of
-           alternating sign matrices*. Electron. J. Combin. 7 (2000).
-
         EXAMPLES::
 
             sage: A = AlternatingSignMatrix([[1, 0, 0],[0, 1, 0],[0, 0, 1]])
@@ -1071,7 +1059,7 @@ class FullyPackedLoop(Element):
         .. NOTE::
 
             by convention, we choose the top left vertex to be even.
-            See [Propp2001]_ and [Striker2015]_.
+            See [Pro2001]_ and [Str2015]_.
 
         EXAMPLES:
 
@@ -1127,7 +1115,7 @@ class FullyPackedLoop(Element):
             ....:     PerfectMatching(rotated_ncp)
             True
 
-            sage: mat = AlternatingSignMatrix([[0,0,0,1,0,0], [0,0,1,-1,1,0], [0,1,0,0,-1,1], [1,0,-1,1,0,0], 
+            sage: mat = AlternatingSignMatrix([[0,0,0,1,0,0], [0,0,1,-1,1,0], [0,1,0,0,-1,1], [1,0,-1,1,0,0],
             ....:     [0,0,1,0,0,0], [0,0,0,0,1,0]])
             sage: fpl = FullyPackedLoop(mat)
             sage: ncp = fpl.link_pattern()
