@@ -200,6 +200,7 @@ class LatinSquare:
             sage: back_circulant(2) == loads(dumps(back_circulant(2)))
             True
         """
+        from sage.misc.persist import dumps
         return dumps(self.square)
 
     def __str__(self):
@@ -340,10 +341,9 @@ class LatinSquare:
             [-1 -1]
             [-1 -1]
         """
-
         for r in range(self.square.nrows()):
             for c in range(self.square.ncols()):
-                self.square[r, c] = -1;
+                self.square[r, c] = -1
 
     def nrows(self):
         """
@@ -354,7 +354,6 @@ class LatinSquare:
             sage: LatinSquare(3).nrows()
             3
         """
-
         return self.square.nrows()
 
     def ncols(self):
@@ -378,7 +377,6 @@ class LatinSquare:
             sage: back_circulant(3).row(0)
             (0, 1, 2)
         """
-
         return self.square.row(x)
 
     def column(self, x):
@@ -403,7 +401,6 @@ class LatinSquare:
             sage: back_circulant(3).list()
             [0, 1, 2, 1, 2, 0, 2, 0, 1]
         """
-
         return self.square.list()
 
     def nr_filled_cells(self):
@@ -417,11 +414,11 @@ class LatinSquare:
             sage: LatinSquare(matrix([[0, -1], [-1, 0]])).nr_filled_cells()
             2
         """
-
         s = 0
         for r in range(self.nrows()):
             for c in range(self.ncols()):
-                if self[r, c] >= 0: s += 1
+                if self[r, c] >= 0:
+                    s += 1
         return s
 
     def actual_row_col_sym_sizes(self):
@@ -449,19 +446,20 @@ class LatinSquare:
             sage: B.actual_row_col_sym_sizes()
             (3, 2, 2)
         """
-
         row_max = self.nrows()
         col_max = self.ncols()
         sym_max = self.nr_distinct_symbols()
 
-        while self.is_empty_row(row_max-1): row_max -= 1
-        while self.is_empty_column(col_max-1): col_max -= 1
+        while self.is_empty_row(row_max-1):
+            row_max -= 1
+        while self.is_empty_column(col_max-1):
+            col_max -= 1
 
         return row_max, col_max, sym_max
 
     def is_empty_column(self, c):
         """
-        Checks if column c of the partial latin square self is empty.
+        Check if column c of the partial latin square self is empty.
 
         EXAMPLES::
 
@@ -477,7 +475,7 @@ class LatinSquare:
 
     def is_empty_row(self, r):
         """
-        Checks if row r of the partial latin square self is empty.
+        Check if row r of the partial latin square self is empty.
 
         EXAMPLES::
 
@@ -510,8 +508,7 @@ class LatinSquare:
             2
         """
         symbols = set(flatten([list(x) for x in list(self.square)]))
-        symbols = [x for x in symbols if x >= 0]
-        return len(symbols)
+        return sum(1 for x in symbols if x >= 0)
 
     def apply_isotopism(self, row_perm, col_perm, sym_perm):
         """
@@ -539,15 +536,15 @@ class LatinSquare:
             [4 0 1 2 3]
             [2 1 4 3 0]
         """
-
-        #Q = matrix(ZZ, self.nrows(), self.ncols())
         Q = LatinSquare(self.nrows(), self.ncols())
 
         for r in range(self.nrows()):
             for c in range(self.ncols()):
                 try:
-                    if self[r, c] < 0: s2 = -1
-                    else: s2 = sym_perm[self[r, c]] - 1
+                    if self[r, c] < 0:
+                        s2 = -1
+                    else:
+                        s2 = sym_perm[self[r, c]] - 1
                 except IndexError:
                     s2 = self[r, c]  # we must be leaving the symbol fixed?
 
@@ -561,11 +558,9 @@ class LatinSquare:
 
         INPUT:
 
-
         -  ``self`` - Partial latin square self (empty cells
            have negative values)
 
-
         OUTPUT: A dictionary cells_map where cells_map[(i,j)] = m means
         that (i,j) is the m-th filled cell in P, while cells_map[m] =
         (i,j).
@@ -603,7 +598,6 @@ class LatinSquare:
              (3, 1): 11,
              (3, 3): 12}
         """
-
         cells_map = {}
         k = 1
 
@@ -611,10 +605,11 @@ class LatinSquare:
             for c in range(self.ncols()):
                 e = self[r, c]
 
-                if e < 0: continue
+                if e < 0:
+                    continue
 
-                cells_map[ (r,c) ] = k
-                cells_map[k] = (r,c)
+                cells_map[(r, c)] = k
+                cells_map[k] = (r, c)
 
                 k += 1
 
@@ -627,10 +622,8 @@ class LatinSquare:
 
         INPUT:
 
-
         -  ``self`` - LatinSquare
 
-
         EXAMPLES::
 
             sage: from sage.combinat.matrices.latin import *
@@ -639,7 +632,6 @@ class LatinSquare:
             sage: B.top_left_empty_cell()
             [3, 4]
         """
-
         for r in range(self.nrows()):
             for c in range(self.ncols()):
                 if self[r, c] < 0:
@@ -674,13 +666,16 @@ class LatinSquare:
             for c in range(n):
                 e = self[r, c]
 
-                if e < 0: continue
+                if e < 0:
+                    continue
 
                 # Entry out of range 0, 1, ..., n-1:
-                if e >= n: return False
+                if e >= n:
+                    return False
 
                 # Entry has already appeared in this row:
-                if e in vals_in_row: return False
+                if e in vals_in_row:
+                    return False
 
                 vals_in_row[e] = True
 
@@ -690,13 +685,16 @@ class LatinSquare:
             for r in range(n):
                 e = self[r, c]
 
-                if e < 0: continue
+                if e < 0:
+                    continue
 
                 # Entry out of range 0, 1, ..., n-1:
-                if e >= n: return False
+                if e >= n:
+                    return False
 
                 # Entry has already appeared in this column:
-                if e in vals_in_col: return False
+                if e in vals_in_col:
+                    return False
 
                 vals_in_col[e] = True
 
@@ -769,12 +767,12 @@ class LatinSquare:
 
         for i in range(n):
             if self[i, c] >= 0:
-                del vals[ self[i, c] ]
+                del vals[self[i, c]]
 
         for j in range(n):
             if self[r, j] >= 0:
                 try:
-                    del vals[ self[r, j] ]
+                    del vals[self[r, j]]
                 except KeyError:
                     # We may have already removed a symbol
                     # in the previous for-loop.
@@ -816,7 +814,7 @@ class LatinSquare:
         if not cells:
             return None
 
-        rc = cells[ ZZ.random_element(len(cells)) ]
+        rc = cells[ZZ.random_element(len(cells))]
 
         return [rc[0], rc[1]]
 
@@ -884,8 +882,7 @@ class LatinSquare:
             sage: B.is_completable()
             True
         """
-
-        return len(dlxcpp_find_completions(self, nr_to_find = 1)) > 0
+        return bool(dlxcpp_find_completions(self, nr_to_find=1))
 
     def gcs(self):
         """
@@ -950,7 +947,7 @@ class LatinSquare:
             sage: P.dlxcpp_has_unique_completion()
             True
         """
-        return len(dlxcpp_find_completions(self, nr_to_find = 2)) == 1
+        return len(dlxcpp_find_completions(self, nr_to_find=2)) == 1
 
     def vals_in_row(self, r):
         """
@@ -971,7 +968,8 @@ class LatinSquare:
 
         for c in range(n):
             e = self[r, c]
-            if e >= 0: vals_in_row[e] = True
+            if e >= 0:
+                vals_in_row[e] = True
 
         return vals_in_row
 
@@ -993,7 +991,8 @@ class LatinSquare:
 
         for r in range(n):
             e = self[r, c]
-            if e >= 0: vals_in_col[e] = True
+            if e >= 0:
+                vals_in_col[e] = True
 
         return vals_in_col
 
@@ -1014,12 +1013,15 @@ class LatinSquare:
             a += r"\hline "
             for c in range(self.ncols()):
                 s = self[r, c]
+                if s < 0:
+                    a += "~"
+                else:
+                    a += str(s)
 
-                if s < 0: a += "~"
-                else: a += str(s)
-
-                if c < self.ncols()-1: a += " & "
-                else: a += "\\\\"
+                if c < self.ncols()-1:
+                    a += " & "
+                else:
+                    a += "\\\\"
         a += r"\hline"
         a += r"\end{array}"
         return a
@@ -1185,22 +1187,26 @@ class LatinSquare:
                 valscol = self.vals_in_col(c)
 
                 # If this is an empty cell of self then we do nothing.
-                if self[r, c] < 0: continue
+                if self[r, c] < 0:
+                    continue
 
                 for e in sorted(set(list(valsrow) + list(valscol))):
                     # These should be constants
-                    c_OFFSET  = e + c*n
-                    r_OFFSET  = e + r*n + n*n
+                    c_OFFSET = e + c*n
+                    r_OFFSET = e + r*n + n*n
                     xy_OFFSET = 2*n*n + r*n + c
 
-                    cmap[(c_OFFSET, r_OFFSET, xy_OFFSET)] = (r,c,e)
+                    cmap[(c_OFFSET, r_OFFSET, xy_OFFSET)] = (r, c, e)
 
                     # The disjoint mate has to be disjoint.
-                    if (not allow_subtrade) and self[r, c] == e: continue
+                    if (not allow_subtrade) and self[r, c] == e:
+                        continue
 
                     # The permissible symbols must come from this row/column.
-                    if e not in valsrow: continue
-                    if e not in valscol: continue
+                    if e not in valsrow:
+                        continue
+                    if e not in valscol:
+                        continue
 
                     dlx_rows.append([c_OFFSET, r_OFFSET, xy_OFFSET])
 
@@ -1211,20 +1217,19 @@ class LatinSquare:
         # have to add 'dummy' rows so that the C++ DLX solver will find
         # a solution.
         used_columns = flatten(dlx_rows)
-        for i in range(0, max_column_nr+1):
-            if not i in used_columns:
+        for i in range(max_column_nr + 1):
+            if i not in used_columns:
                 dlx_rows.append([i])
 
         return dlx_rows, cmap
 
-
-    def find_disjoint_mates(self, nr_to_find = None, allow_subtrade = False):
+    def find_disjoint_mates(self, nr_to_find=None, allow_subtrade=False):
         r"""
         .. warning::
 
-           If allow_subtrade is ``True`` then we may return a partial
-           latin square that is *not* disjoint to ``self``. In that case,
-           use bitrade(P, Q) to get an actual bitrade.
+            If allow_subtrade is ``True`` then we may return a partial
+            latin square that is *not* disjoint to ``self``. In that case,
+            use bitrade(P, Q) to get an actual bitrade.
 
         EXAMPLES::
 
@@ -1259,13 +1264,15 @@ class LatinSquare:
             Q = deepcopy(self)
 
             for y in x:
-                if len(dlx_rows[y]) == 1: continue # dummy row
+                if len(dlx_rows[y]) == 1:
+                    continue  # dummy row
                 (r, c, e) = cmap[tuple(dlx_rows[y])]
                 Q[r, c] = e
 
             yield Q
 
-            if nr_to_find is not None and nr_found >= nr_to_find: return
+            if nr_to_find is not None and nr_found >= nr_to_find:
+                return
 
     def contained_in(self, Q):
         r"""
@@ -1573,13 +1580,14 @@ def cells_map_as_square(cells_map, n):
     for r in range(n):
         for c in range(n):
             try:
-                L[r, c] = cells_map[ (r,c) ]
+                L[r, c] = cells_map[(r, c)]
             except KeyError:
                 # There is no cell (r,c) so skip it
                 L[r, c] = -1
 
     return L
 
+
 def beta1(rce, T1, T2):
     """
     Find the unique (x, c, e) in T2 such that (r, c, e) is in T1.
@@ -1607,7 +1615,6 @@ def beta1(rce, T1, T2):
         sage: beta1([0, 0, 0], T1, T2)
         (1, 0, 0)
     """
-
     r = rce[0]
     c = rce[1]
     e = rce[2]
@@ -1616,9 +1623,10 @@ def beta1(rce, T1, T2):
     assert e >= 0
 
     for x in range(T1.nrows()):
-        if T2[x, c] == e: return (x, c, e)
+        if T2[x, c] == e:
+            return (x, c, e)
 
-    raise PairNotBitrade
+    raise ValueError
 
 
 def beta2(rce, T1, T2):
@@ -1649,7 +1657,6 @@ def beta2(rce, T1, T2):
         sage: beta2([0, 0, 0], T1, T2)
         (0, 1, 0)
     """
-
     r = rce[0]
     c = rce[1]
     e = rce[2]
@@ -1658,9 +1665,11 @@ def beta2(rce, T1, T2):
     assert e >= 0
 
     for x in range(T1.ncols()):
-        if T2[r, x] == e: return (r, x, e)
+        if T2[r, x] == e:
+            return (r, x, e)
+
+    raise ValueError
 
-    raise PairNotBitrade
 
 def beta3(rce, T1, T2):
     """
@@ -1691,7 +1700,6 @@ def beta3(rce, T1, T2):
         sage: beta3([0, 0, 0], T1, T2)
         (0, 0, 4)
     """
-
     r = rce[0]
     c = rce[1]
     e = rce[2]
@@ -1702,9 +1710,11 @@ def beta3(rce, T1, T2):
     # fixme this range could be iffy if we
     # work with latin bitrade rectangles...
     for x in range(T1.nrows()):
-        if T2[r, c] == x: return (r, c, x)
+        if T2[r, c] == x:
+            return (r, c, x)
+
+    raise ValueError
 
-    raise PairNotBitrade
 
 def tau1(T1, T2, cells_map):
     r"""
@@ -1745,18 +1755,21 @@ def tau1(T1, T2, cells_map):
         for c in range(T1.ncols()):
             e = T1[r, c]
 
-            if e < 0: continue
+            if e < 0:
+                continue
 
-            (r2, c2, e2) = beta2( (r,c,e), T1, T2)
-            (r3, c3, e3) = beta3( (r2,c2,e2), T2, T1)
+            (r2, c2, e2) = beta2((r, c, e), T1, T2)
+            (r3, c3, e3) = beta3((r2, c2, e2), T2, T1)
 
-            x[ cells_map[(r,c)] ] = cells_map[ (r3,c3) ]
+            x[cells_map[(r, c)]] = cells_map[(r3, c3)]
 
-    x.pop(0) # remove the head of the list since we
-             # have permutations on 1..(something).
+    x.pop(0)
+    # remove the head of the list since we
+    # have permutations on 1..(something).
 
     return Permutation(x)
 
+
 def tau2(T1, T2, cells_map):
     r"""
     The definition of `\tau_2` is
@@ -1796,18 +1809,21 @@ def tau2(T1, T2, cells_map):
         for c in range(T1.ncols()):
             e = T1[r, c]
 
-            if e < 0: continue
+            if e < 0:
+                continue
 
-            (r2, c2, e2) = beta3( (r,c,e), T1, T2)
-            (r3, c3, e3) = beta1( (r2,c2,e2), T2, T1)
+            (r2, c2, e2) = beta3((r, c, e), T1, T2)
+            (r3, c3, e3) = beta1((r2, c2, e2), T2, T1)
 
-            x[ cells_map[(r,c)] ] = cells_map[ (r3,c3) ]
+            x[cells_map[(r, c)]] = cells_map[(r3, c3)]
 
-    x.pop(0) # remove the head of the list since we
-             # have permutations on 1..(something).
+    x.pop(0)
+    # remove the head of the list since we
+    # have permutations on 1..(something).
 
     return Permutation(x)
 
+
 def tau3(T1, T2, cells_map):
     r"""
     The definition of `\tau_3` is
@@ -1847,18 +1863,21 @@ def tau3(T1, T2, cells_map):
         for c in range(T1.ncols()):
             e = T1[r, c]
 
-            if e < 0: continue
+            if e < 0:
+                continue
 
-            (r2, c2, e2) = beta1( (r,c,e), T1, T2)
-            (r3, c3, e3) = beta2( (r2,c2,e2), T2, T1)
+            (r2, c2, e2) = beta1((r, c, e), T1, T2)
+            (r3, c3, e3) = beta2((r2, c2, e2), T2, T1)
 
-            x[ cells_map[(r,c)] ] = cells_map[ (r3,c3) ]
+            x[cells_map[(r, c)]] = cells_map[(r3, c3)]
 
-    x.pop(0) # remove the head of the list since we
-             # have permutations on 1..(something).
+    x.pop(0)
+    # remove the head of the list since we
+    # have permutations on 1..(something).
 
     return Permutation(x)
 
+
 def back_circulant(n):
     """
     The back-circulant latin square of order n is the Cayley table for
@@ -1866,9 +1885,7 @@ def back_circulant(n):
 
     INPUT:
 
-
-    -  ``n`` - int; order of the latin square.
-
+    -  ``n`` -- int; order of the latin square.
 
     EXAMPLES::
 
@@ -1880,7 +1897,6 @@ def back_circulant(n):
         [3 4 0 1 2]
         [4 0 1 2 3]
     """
-
     assert n >= 1
 
     L = LatinSquare(n, n)
@@ -1891,6 +1907,7 @@ def back_circulant(n):
 
     return L
 
+
 def forward_circulant(n):
     """
     The forward-circulant latin square of order n is the Cayley table
@@ -1898,9 +1915,7 @@ def forward_circulant(n):
 
     INPUT:
 
-
-    -  ``n`` - int; order of the latin square.
-
+    -  ``n`` -- int; order of the latin square.
 
     EXAMPLES::
 
@@ -1912,7 +1927,6 @@ def forward_circulant(n):
         [3 2 1 0 4]
         [4 3 2 1 0]
     """
-
     assert n >= 1
 
     L = LatinSquare(n, n)
@@ -1923,6 +1937,7 @@ def forward_circulant(n):
 
     return L
 
+
 def direct_product(L1, L2, L3, L4):
     """
     The 'direct product' of four latin squares L1, L2, L3, L4 of order
@@ -1951,7 +1966,6 @@ def direct_product(L1, L2, L3, L4):
         [6 7 4 5 2 3 0 1]
         [7 6 5 4 3 2 1 0]
     """
-
     assert L1.nrows() == L2.nrows() == L3.nrows() == L4.nrows()
     assert L1.ncols() == L2.ncols() == L3.ncols() == L4.ncols()
     assert L1.nrows() == L1.ncols()
@@ -1977,9 +1991,7 @@ def elementary_abelian_2group(s):
 
     INPUT:
 
-
-    -  ``s`` - int; order of the latin square will be 2s.
-
+    -  ``s`` -- int; order of the latin square will be 2s.
 
     EXAMPLES::
 
@@ -1994,7 +2006,6 @@ def elementary_abelian_2group(s):
         [6 7 4 5 2 3 0 1]
         [7 6 5 4 3 2 1 0]
     """
-
     assert s > 0
 
     if s == 1:
@@ -2019,25 +2030,25 @@ def elementary_abelian_2group(s):
                 L[r+offset, c+offset] = L_prev[r, c]
     return L
 
+
 def coin():
     """
-    Simulates a fair coin (returns True or False) using
+    Simulate a fair coin (returns True or False) using
     ZZ.random_element(2).
 
     EXAMPLES::
 
-        sage: from sage.combinat.matrices.latin import *
+        sage: from sage.combinat.matrices.latin import coin
         sage: x = coin()
         sage: x == 0 or x == 1
         True
     """
-
     return ZZ.random_element(2) == 0
 
 
 def next_conjugate(L):
     """
-    Permutes L[r, c] = e to the conjugate L[c, e] = r.
+    Permute L[r, c] = e to the conjugate L[c, e] = r.
 
     We assume that L is an n by n matrix and has values in the range 0,
     1, ..., n-1.
@@ -2063,7 +2074,6 @@ def next_conjugate(L):
         sage: L == next_conjugate(next_conjugate(next_conjugate(L)))
         True
     """
-
     assert L.nrows() == L.ncols()
 
     n = L.nrows()
@@ -2079,6 +2089,7 @@ def next_conjugate(L):
 
     return C
 
+
 def row_containing_sym(L, c, x):
     """
     Given an improper latin square L with L[r1, c] = L[r2, c] = x,
@@ -2098,12 +2109,12 @@ def row_containing_sym(L, c, x):
         sage: c == 1 or c == 2
         True
     """
-
     r1 = -1
     r2 = -1
 
     for r in range(L.nrows()):
-        if r1 >= 0 and r2 >= 0: break
+        if r1 >= 0 and r2 >= 0:
+            break
 
         if L[r, c] == x and r1 < 0:
             r1 = r
@@ -2115,8 +2126,8 @@ def row_containing_sym(L, c, x):
 
     assert r1 >= 0 and r2 >= 0
 
-    if coin():  return r1
-    else:       return r2
+    return r1 if coin() else r2
+
 
 def column_containing_sym(L, r, x):
     """
@@ -2142,7 +2153,8 @@ def column_containing_sym(L, r, x):
     c2 = -1
 
     for c in range(L.ncols()):
-        if c1 >= 0 and c2 >= 0: break
+        if c1 >= 0 and c2 >= 0:
+            break
 
         if L[r, c] == x and c1 < 0:
             c1 = c
@@ -2154,16 +2166,18 @@ def column_containing_sym(L, r, x):
 
     assert c1 >= 0 and c2 >= 0
 
-    if coin():  return c1
-    else:       return c2
+    return c1 if coin() else c2
 
-def LatinSquare_generator(L_start, check_assertions = False):
+
+def LatinSquare_generator(L_start, check_assertions=False):
     """
     Generator for a sequence of uniformly distributed latin squares,
-    given L_start as the initial latin square. This code implements
+    given L_start as the initial latin square.
+
+    This code implements
     the Markov chain algorithm of Jacobson and Matthews (1996), see
     below for the BibTex entry. This generator will never throw the
-    StopIteration exception, so it provides an infinite sequence of
+    ``StopIteration`` exception, so it provides an infinite sequence of
     latin squares.
 
     EXAMPLES:
@@ -2183,7 +2197,8 @@ def LatinSquare_generator(L_start, check_assertions = False):
        distributed random Latin squares", Journal of Combinatorial Designs,
        4 (1996)
     """
-    if check_assertions: assert L_start.is_latin_square()
+    if check_assertions:
+        assert L_start.is_latin_square()
 
     n = L_start.nrows()
 
@@ -2198,7 +2213,8 @@ def LatinSquare_generator(L_start, check_assertions = False):
 
     while True:
         if proper:
-            if check_assertions: assert L.is_latin_square()
+            if check_assertions:
+                assert L.is_latin_square()
 
             #################################
             # Update the other two conjugates
@@ -2224,8 +2240,10 @@ def LatinSquare_generator(L_start, check_assertions = False):
             if check_assertions:
                 r2 = 0
                 c2 = 0
-                while L[r1, c2] != y: c2 += 1
-                while L[r2, c1] != y: r2 += 1
+                while L[r1, c2] != y:
+                    c2 += 1
+                while L[r2, c1] != y:
+                    r2 += 1
 
                 assert L_erc[y, r1] == c2
                 assert L_cer[c1, y] == r2
@@ -2233,8 +2251,10 @@ def LatinSquare_generator(L_start, check_assertions = False):
             c2 = L_erc[y, r1]
             r2 = L_cer[c1, y]
 
-            if check_assertions: assert L[r1, c2] == y
-            if check_assertions: assert L[r2, c1] == y
+            if check_assertions:
+                assert L[r1, c2] == y
+            if check_assertions:
+                assert L[r2, c1] == y
 
             L[r1, c1] = y
             L[r1, c2] = x
@@ -2250,7 +2270,7 @@ def LatinSquare_generator(L_start, check_assertions = False):
                 # z and y have positive coefficients
                 # x is the improper term with a negative coefficient
                 proper = False
-        else: # improper square,
+        else:  # improper square,
             # L[r2, c2] = y + z - x
             # y and z are proper while x is the
             # improper symbol in the cell L[r2, c2].
@@ -2258,8 +2278,10 @@ def LatinSquare_generator(L_start, check_assertions = False):
             r1 = row_containing_sym(L, c2, x)
             c1 = column_containing_sym(L, r2, x)
 
-            if check_assertions: assert L[r1, c2] == x
-            if check_assertions: assert L[r2, c1] == x
+            if check_assertions:
+                assert L[r1, c2] == x
+            if check_assertions:
+                assert L[r2, c1] == x
 
             # choose one of the proper symbols
             # uniformly at random (we will use whatever
@@ -2275,7 +2297,7 @@ def LatinSquare_generator(L_start, check_assertions = False):
             if L[r1, c1] == y:
                 L[r1, c1] = x
                 proper = True
-            else: # got another improper square
+            else:  # got another improper square
                 z = L[r1, c1]
                 x, y = y, x
                 r2 = r1
@@ -2283,7 +2305,7 @@ def LatinSquare_generator(L_start, check_assertions = False):
 
                 # Now we have L[r2, c2] = z+y-x as
                 # usual
-                proper = False # for emphasis
+                proper = False  # for emphasis
 
 
 def group_to_LatinSquare(G):
@@ -2367,6 +2389,7 @@ def alternating_group_bitrade_generators(m):
 
     return (a, b, c, G)
 
+
 def pq_group_bitrade_generators(p, q):
     """
     Generators for a group of order pq where p and q are primes such
@@ -2378,7 +2401,6 @@ def pq_group_bitrade_generators(p, q):
         sage: pq_group_bitrade_generators(3,7)
         ((2,3,5)(4,7,6), (1,2,3,4,5,6,7), (1,4,2)(3,5,6), Permutation Group with generators [(2,3,5)(4,7,6), (1,2,3,4,5,6,7)])
     """
-
     assert is_prime(p)
     assert is_prime(q)
     assert (q % p) == 1
@@ -2403,11 +2425,12 @@ def pq_group_bitrade_generators(p, q):
         cycle = []
         for k in range(p):
             x = (1 + (i-1)*beta**k) % q
-            if x == 0: x = q
+            if x == 0:
+                x = q
 
             seenValues[x] = True
             cycle.append(x)
-        P.append(tuple(map(Integer,cycle)))
+        P.append(tuple(map(Integer, cycle)))
 
     G = PermutationGroup([P, Q])
     assert G.order() == p*q
@@ -2439,12 +2462,12 @@ def p3_group_bitrade_generators(p):
     c = F.gen(3)
 
     rels = []
-    rels.append( a**p )
-    rels.append( b**p )
-    rels.append( c**p )
-    rels.append( a*b*((b*a*c)**(-1)) )
-    rels.append( c*a*((a*c)**(-1)) )
-    rels.append( c*b*((b*c)**(-1)) )
+    rels.append(a**p)
+    rels.append(b**p)
+    rels.append(c**p)
+    rels.append(a*b*((b*a*c)**(-1)))
+    rels.append(c*a*((a*c)**(-1)))
+    rels.append(c*b*((b*c)**(-1)))
 
     G = F.FactorGroupFpGroupByRels(rels)
 
@@ -2471,7 +2494,6 @@ def check_bitrade_generators(a, b, c):
         sage: check_bitrade_generators(a, b, gap('()'))
         False
     """
-
     A = PermutationGroup([a])
     B = PermutationGroup([b])
     C = PermutationGroup([c])
@@ -2501,12 +2523,8 @@ def is_bitrade(T1, T2):
         sage: is_bitrade(T1, T2)
         True
     """
-
-    if not is_disjoint(T1, T2): return False
-    if not is_same_shape(T1, T2): return False
-    if not is_row_and_col_balanced(T1, T2): return False
-
-    return True
+    return (is_disjoint(T1, T2) and is_same_shape(T1, T2) and
+            is_row_and_col_balanced(T1, T2))
 
 
 def is_primary_bitrade(a, b, c, G):
@@ -2521,10 +2539,7 @@ def is_primary_bitrade(a, b, c, G):
         sage: is_primary_bitrade(a, b, c, G)
         True
     """
-
-    H = PermutationGroup([a, b, c])
-
-    return G == H
+    return G == PermutationGroup([a, b, c])
 
 
 def tau_to_bitrade(t1, t2, t3):
@@ -2557,7 +2572,6 @@ def tau_to_bitrade(t1, t2, t3):
         [2 3 4 0 1]
         [3 4 0 1 2]
     """
-
     c1 = t1.to_cycles()
     c2 = t2.to_cycles()
     c3 = t3.to_cycles()
@@ -2586,11 +2600,12 @@ def tau_to_bitrade(t1, t2, t3):
     for r in range(len(c1)):
         for c in range(len(c2)):
             for s in range(len(c3)):
-                nr_common = len(reduce(set.intersection, \
-                    [set(c1[r]), set(c2[c]), set(c3[s])]))
+                nr_common = len(reduce(set.intersection,
+                                       [set(c1[r]), set(c2[c]), set(c3[s])]))
                 assert nr_common in [0, 1]
 
-                if nr_common == 1: T1[r, c] = s
+                if nr_common == 1:
+                    T1[r, c] = s
 
     for cycle in c1:
         for pt1 in cycle:
@@ -2630,7 +2645,6 @@ def bitrade_from_group(a, b, c, G):
         [ 2  1  3 -1]
         [ 0  3 -1  2]
     """
-
     hom = gap.ActionHomomorphism(G, gap.RightCosets(G, gap.TrivialSubgroup(G)), gap.OnRight)
 
     t1 = gap.Image(hom, a)
@@ -2665,16 +2679,16 @@ def is_disjoint(T1, T2):
         sage: is_disjoint(T1, T2)
         True
     """
-
     for i in range(T1.nrows()):
         for j in range(T1.ncols()):
-            if T1[i, j] < 0 and T2[i, j] < 0: continue
-
+            if T1[i, j] < 0 and T2[i, j] < 0:
+                continue
             if T1[i, j] == T2[i, j]:
                 return False
 
     return True
 
+
 def is_same_shape(T1, T2):
     """
     Two partial latin squares T1, T2 have the same shape if T1[r, c] =
@@ -2690,11 +2704,12 @@ def is_same_shape(T1, T2):
         sage: is_same_shape(forward_circulant(5), LatinSquare(5))
         False
     """
-
     for i in range(T1.nrows()):
         for j in range(T1.ncols()):
-            if T1[i, j] < 0 and T2[i, j] < 0: continue
-            if T1[i, j] >= 0 and T2[i, j] >= 0: continue
+            if T1[i, j] < 0 and T2[i, j] < 0:
+                continue
+            if T1[i, j] >= 0 and T2[i, j] >= 0:
+                continue
 
             return False
 
@@ -2719,25 +2734,24 @@ def is_row_and_col_balanced(T1, T2):
         sage: is_row_and_col_balanced(T1, T2)
         False
     """
-
     for r in range(T1.nrows()):
         val1 = set(x for x in T1.row(r) if x >= 0)
         val2 = set(x for x in T2.row(r) if x >= 0)
-
-        if val1 != val2: return False
+        if val1 != val2:
+            return False
 
     for c in range(T1.ncols()):
         val1 = set(x for x in T1.column(c) if x >= 0)
         val2 = set(x for x in T2.column(c) if x >= 0)
-
-        if val1 != val2: return False
+        if val1 != val2:
+            return False
 
     return True
 
 
 def dlxcpp_rows_and_map(P):
     """
-    Internal function for dlxcpp_find_completions. Given a partial
+    Internal function for ``dlxcpp_find_completions``. Given a partial
     latin square P we construct a list of rows of a 0-1 matrix M such
     that an exact cover of M corresponds to a completion of P to a
     latin square.
@@ -2763,7 +2777,6 @@ def dlxcpp_rows_and_map(P):
           (3, 5, 9): (0, 1, 1),
           (3, 7, 11): (1, 1, 1)})
     """
-
     assert P.nrows() == P.ncols()
 
     n = P.nrows()
@@ -2785,26 +2798,26 @@ def dlxcpp_rows_and_map(P):
 
             for e in range(n):
                 # These should be constants
-                c_OFFSET  = e + c*n
-                r_OFFSET  = e + r*n + n*n
+                c_OFFSET = e + c*n
+                r_OFFSET = e + r*n + n*n
                 xy_OFFSET = 2*n*n + r*n + c
 
-                cmap[(c_OFFSET, r_OFFSET, xy_OFFSET)] = (r,c,e)
-
-                #if P[r, c] >= 0: continue
+                cmap[(c_OFFSET, r_OFFSET, xy_OFFSET)] = (r, c, e)
 
                 # We only want the correct value to pop in here
-                if P[r, c] >= 0 and P[r, c] != e: continue
-
-                if P[r, c] < 0 and e in valsrow: continue
-                if P[r, c] < 0 and e in valscol: continue
+                if P[r, c] >= 0 and P[r, c] != e:
+                    continue
+                if P[r, c] < 0 and e in valsrow:
+                    continue
+                if P[r, c] < 0 and e in valscol:
+                    continue
 
                 dlx_rows.append([c_OFFSET, r_OFFSET, xy_OFFSET])
 
     return dlx_rows, cmap
 
 
-def dlxcpp_find_completions(P, nr_to_find = None):
+def dlxcpp_find_completions(P, nr_to_find=None):
     """
     Return a list of all latin squares L of the same order as P such
     that P is contained in L. The optional parameter nr_to_find
