@@ -104,7 +104,7 @@ is an involution::
     [4, 3, 1] / [2]
 
 The :meth:`jacobi_trudi()` method computes the Jacobi-Trudi matrix. See
-[Mac95]_ for a definition and discussion.
+[Mac1995]_ for a definition and discussion.
 
 ::
 
@@ -122,11 +122,6 @@ This example shows how to compute the corners of a skew partition.
     sage: SkewPartition([[4,3,1],[2]]).outer_corners()
     [(0, 3), (1, 2), (2, 0)]
 
-REFERENCES:
-
-.. [Mac95] Macdonald I.-G., (1995), "Symmetric Functions and Hall
-   Polynomials", Oxford Science Publication
-
 AUTHORS:
 
 - Mike Hansen: Initial version
@@ -925,7 +920,7 @@ class SkewPartition(CombinatorialElement):
         In other words, the Frobenius rank of `\lambda / \mu` is the
         number of rows in the Jacobi-Trudi matrix of `\lambda / \mu`
         which don't contain `h_0`. Further definitions have been
-        considered in [Stan2002]_ (where Frobenius rank is just being
+        considered in [Sta2002]_ (where Frobenius rank is just being
         called rank).
 
         If `\mu` is the empty shape, then the Frobenius rank of
@@ -933,14 +928,6 @@ class SkewPartition(CombinatorialElement):
         partition `\lambda` (see
         :meth:`~sage.combinat.partition.Partition.frobenius_rank()`).
 
-        REFERENCES:
-
-        .. [Stan2002] Richard P. Stanley,
-           *The rank and minimal border strip decompositions of a
-           skew partition*,
-           J. Combin. Theory Ser. A 100 (2002), pp. 349-375.
-           :arxiv:`math/0109092v1`.
-
         EXAMPLES::
 
             sage: SkewPartition([[8,8,7,4], [4,1,1]]).frobenius_rank()
