@@ -14,7 +14,7 @@ from sage.structure.parent import Parent
 from sage.structure.element import get_coercion_model
 from sage.structure.unique_representation import UniqueRepresentation
 from sage.modules.free_module import is_FreeModule
-from sage.misc.cachefunc import cached_method
+from sage.misc.cachefunc import cached_method, cached_function
 from sage.rings.all import ZZ, QQ, RDF, CommutativeRing
 from sage.categories.fields import Fields
 
@@ -81,7 +81,12 @@ def Polyhedra(base_ring, ambient_dim, backend=None):
         sage: Polyhedra(RR, 3)
         Traceback (most recent call last):
         ...
-        ValueError: no appropriate backend for computations with Real Field with 53 bits of precision
+        ValueError: no default backend for computations with Real Field with 53 bits of precision
+        sage: Polyhedra(QQ[I], 2)
+        Traceback (most recent call last):
+        ...
+        ValueError: invalid base ring: Number Field in I with defining polynomial x^2 + 1 with I = 1*I cannot be coerced to a real field
+
     """
     if backend is None:
         if base_ring is ZZ or base_ring is QQ:
@@ -92,11 +97,12 @@ def Polyhedra(base_ring, ambient_dim, backend=None):
             # TODO: find a more robust way of checking that the coefficients are indeed
             # real numbers
             if not RDF.has_coerce_map_from(base_ring):
-                raise ValueError("invalid base ring")
+                raise ValueError("invalid base ring: {} cannot be coerced to a real field".format(base_ring))
             backend = 'field'
         else:
-            raise ValueError("no appropriate backend for computations with {}".format(base_ring))
+            raise ValueError("no default backend for computations with {}".format(base_ring))
 
+    from sage.symbolic.ring import SR
     if backend == 'ppl' and base_ring is QQ:
         return Polyhedra_QQ_ppl(base_ring, ambient_dim, backend)
     elif backend == 'ppl' and base_ring is ZZ:
@@ -105,6 +111,8 @@ def Polyhedra(base_ring, ambient_dim, backend=None):
         return Polyhedra_QQ_normaliz(base_ring, ambient_dim, backend)
     elif backend == 'normaliz' and base_ring is ZZ:
         return Polyhedra_ZZ_normaliz(base_ring, ambient_dim, backend)
+    elif backend == 'normaliz' and (base_ring is SR or base_ring.is_exact()):
+        return Polyhedra_normaliz(base_ring, ambient_dim, backend)
     elif backend == 'cdd' and base_ring in (ZZ, QQ):
         return Polyhedra_QQ_cdd(QQ, ambient_dim, backend)
     elif backend == 'cdd' and base_ring is RDF:
@@ -543,7 +551,7 @@ class Polyhedra_base(UniqueRepresentation, Parent):
         Hrep = [polyhedron.inequality_generator(), polyhedron.equation_generator()]
         return self._element_constructor_(Vrep, Hrep, **kwds)
 
-    def base_extend(self, base_ring, backend=None):
+    def base_extend(self, base_ring, backend=None, ambient_dim=None):
         """
         Return the base extended parent.
 
@@ -551,6 +559,8 @@ class Polyhedra_base(UniqueRepresentation, Parent):
 
         - ``base_ring``, ``backend`` -- see
           :func:`~sage.geometry.polyhedron.constructor.Polyhedron`.
+        - ``ambient_dim`` -- if not ``None`` change ambient dimension
+          accordingly.
 
         EXAMPLES::
 
@@ -559,6 +569,8 @@ class Polyhedra_base(UniqueRepresentation, Parent):
             Polyhedra in QQ^3
             sage: Polyhedra(ZZ,3).an_element().base_extend(QQ)
             A 3-dimensional polyhedron in QQ^3 defined as the convex hull of 4 vertices
+            sage: Polyhedra(QQ, 2).base_extend(ZZ)
+            Polyhedra in QQ^2
 
         TESTS:
 
@@ -567,15 +579,15 @@ class Polyhedra_base(UniqueRepresentation, Parent):
             sage: P = Polyhedra(ZZ,3).base_extend(QQ, backend='field')
             sage: P.backend()
             'field'
-
         """
-        if (self.base_ring().has_coerce_map_from(base_ring)
-            and (backend is None or self.backend() == backend)):
-            return self
-        elif base_ring.has_coerce_map_from(self.base_ring()):
-            return Polyhedra(base_ring, self.ambient_dim(), backend=backend)
+        if self.base_ring().has_coerce_map_from(base_ring):
+            new_ring = self.base_ring()
+        else:
+            new_ring = self._coerce_base_ring(base_ring)
 
-    def change_ring(self, base_ring, backend=None):
+        return self.change_ring(new_ring, backend=backend, ambient_dim=ambient_dim)
+
+    def change_ring(self, base_ring, backend=None, ambient_dim=None):
         """
         Return the parent with the new base ring.
 
@@ -583,6 +595,8 @@ class Polyhedra_base(UniqueRepresentation, Parent):
 
         - ``base_ring``, ``backend`` -- see
           :func:`~sage.geometry.polyhedron.constructor.Polyhedron`.
+        - ``ambient_dim`` -- if not ``None`` change ambient dimension
+          accordingly.
 
         EXAMPLES::
 
@@ -591,8 +605,27 @@ class Polyhedra_base(UniqueRepresentation, Parent):
             Polyhedra in QQ^3
             sage: Polyhedra(ZZ,3).an_element().change_ring(QQ)
             A 3-dimensional polyhedron in QQ^3 defined as the convex hull of 4 vertices
-            """
-        return Polyhedra(base_ring, self.ambient_dim(), backend=backend)
+
+            sage: Polyhedra(RDF, 3).change_ring(QQ).backend()
+            'cdd'
+            sage: Polyhedra(QQ, 3).change_ring(ZZ, ambient_dim=4)
+            Polyhedra in ZZ^4
+            sage: Polyhedra(QQ, 3, backend='cdd').change_ring(QQ, ambient_dim=4).backend()
+            'cdd'
+        """
+        if ambient_dim is None:
+            ambient_dim = self.ambient_dim()
+
+        if base_ring == self.base_ring() and \
+                ambient_dim == self.ambient_dim() and \
+                (backend is None or backend == self.backend()):
+            return self
+
+        # if not specified try the same backend
+        if backend is None and does_backend_handle_base_ring(base_ring, self.backend()):
+            return Polyhedra(base_ring, ambient_dim, backend=self.backend())
+
+        return Polyhedra(base_ring, ambient_dim, backend=backend)
 
     def _coerce_base_ring(self, other):
         r"""
@@ -981,3 +1014,24 @@ class Polyhedra_field(Polyhedra_base):
         Hrep = [polyhedron.inequality_generator(), polyhedron.equation_generator()]
         return self._element_constructor_(Vrep, Hrep,
                                           Vrep_minimal=True, Hrep_minimal=True, **kwds)
+
+@cached_function
+def does_backend_handle_base_ring(base_ring, backend):
+    r"""
+    Return true, if ``backend`` can handle ``base_ring``.
+
+    EXAMPLES::
+
+        sage: from sage.geometry.polyhedron.parent import does_backend_handle_base_ring
+        sage: does_backend_handle_base_ring(QQ, 'ppl')
+        True
+        sage: does_backend_handle_base_ring(QQ[sqrt(5)], 'ppl')
+        False
+        sage: does_backend_handle_base_ring(QQ[sqrt(5)], 'field')
+        True
+    """
+    try:
+        Polyhedra(base_ring, 0, backend)
+    except ValueError:
+        return False
+    return True
