@@ -13,6 +13,7 @@ The methods defined here appear in :mod:`sage.graphs.graph_generators`.
 # Distributed  under  the  terms  of  the  GNU  General  Public  License (GPL)
 #                         http://www.gnu.org/licenses/
 ###########################################################################
+from __future__ import print_function, division
 from six.moves import range
 import sys
 # import from Sage library
@@ -35,7 +36,7 @@ def RandomGNP(n, p, seed=None, fast=True, algorithm='Sage'):
       number generator (default: ``None``).
 
     - ``fast`` -- boolean set to True (default) to use the algorithm with
-      time complexity in `O(n+m)` proposed in [BatBra2005]_. It is designed
+      time complexity in `O(n+m)` proposed in [BB2005a]_. It is designed
       for generating large sparse graphs. It is faster than other algorithms for
       *LARGE* instances (try it to know whether it is useful for you).
 
@@ -49,14 +50,9 @@ def RandomGNP(n, p, seed=None, fast=True, algorithm='Sage'):
 
     REFERENCES:
 
-    .. [ErdRen1959] \P. Erdos and A. Renyi. On Random Graphs, Publ.
-       Math. 6, 290 (1959).
+    - [ER1959]_
 
-    .. [Gilbert1959] \E. N. Gilbert. Random Graphs, Ann. Math. Stat.,
-       30, 1141 (1959).
-
-    .. [BatBra2005] \V. Batagelj and U. Brandes. Efficient generation of
-       large random networks. Phys. Rev. E, 71, 036113, 2005.
+    - [Gil1959]_
 
     PLOTTING: When plotting, this graph will use the default spring-layout
     algorithm, unless a position dictionary is specified.
@@ -85,7 +81,7 @@ def RandomGNP(n, p, seed=None, fast=True, algorithm='Sage'):
         ....:     for m in range(3):
         ....:         n.append(g[3*i + m].plot(vertex_size=50, vertex_labels=False))
         ....:     j.append(n)
-        sage: G = sage.plot.graphics.GraphicsArray(j)
+        sage: G = graphics_array(j)
         sage: G.show() # long time
         sage: graphs.RandomGNP(4,1)
         Complete graph: Graph on 4 vertices
@@ -100,7 +96,7 @@ def RandomGNP(n, p, seed=None, fast=True, algorithm='Sage'):
         sage: graphs.RandomGNP(50,.2, algorithm="Sage").size()
         243
         sage: graphs.RandomGNP(50,.2, algorithm="networkx").size()
-        260     # 32-bit 
+        260     # 32-bit
         245     # 64-bit
     """
     if n < 0:
@@ -173,7 +169,7 @@ def RandomBarabasiAlbert(n, m, seed=None):
         ....:     for m in range(3):
         ....:         n.append(g[3*i + m].plot(vertex_size=50, vertex_labels=False))
         ....:     j.append(n)
-        sage: G = sage.plot.graphics.GraphicsArray(j)
+        sage: G = graphics_array(j)
         sage: G.show()  # long time
 
     When `m = 1`, the generated graph is a tree::
@@ -270,10 +266,10 @@ def RandomRegularBipartite(n1, n2, d1, set_position=False):
 
     The bipartite graph has `n1 * d1` edges. Hence, `n2` must divide `n1 * d1`.
     Each vertex of the set of cardinality `n1` has degree `d1` (which can be at
-    most `n2`) and each vertex in the set of cardinality `n2` has degree 
+    most `n2`) and each vertex in the set of cardinality `n2` has degree
     `(n1 * d1) / n2`. The bipartite graph has no multiple edges.
 
-    This generator implements an algorithm inspired by that of [MW1990]_ for 
+    This generator implements an algorithm inspired by that of [MW1990]_ for
     the uniform generation of random regular bipartite graphs. It performs well
     when `d1 = o(n2^{1/3})` or (`n2 - d1 = o(n2^{1/3})`). In other cases, the
     running time can be huge. Note that the currently implemented algorithm
@@ -286,7 +282,7 @@ def RandomRegularBipartite(n1, n2, d1, set_position=False):
     - ``d1`` -- degree of the vertices in the set of cardinality `n1`.
 
     - ``set_position`` -- boolean (default ``False``); if set to ``True``, we
-      assign positions to the vertices so that the set of cardinality `n1` is 
+      assign positions to the vertices so that the set of cardinality `n1` is
       on the line `y=1` and the set of cardinality `n2` is on the line `y=0`.
 
     EXAMPLES::
@@ -434,7 +430,7 @@ def RandomBlockGraph(m, k, kmax=None, incidence_structure=False):
         - :meth:`~sage.graphs.graph.Graph.is_block_graph` -- test if a graph is a block graph
         - :meth:`~sage.graphs.generic_graph.GenericGraph.blocks_and_cut_vertices`
         - :meth:`~sage.graphs.generic_graph.GenericGraph.blocks_and_cuts_tree`
-        - :meth:`~sage.combinat.designs.incidence_structures.IncidenceStructure` 
+        - :meth:`~sage.combinat.designs.incidence_structures.IncidenceStructure`
 
     INPUT:
 
@@ -541,7 +537,7 @@ def RandomBlockGraph(m, k, kmax=None, incidence_structure=False):
     if m == 1:
         # A block graph with a single block is a clique
         IS = [ list(range(randint(k, kmax))) ]
-        
+
     elif kmax == 2:
         # A block graph with blocks of order 2 is a tree
         IS = [ list(e) for e in RandomTree(m+1).edges(labels=False) ]
@@ -567,7 +563,7 @@ def RandomBlockGraph(m, k, kmax=None, incidence_structure=False):
 
     if incidence_structure:
         return IS
-    
+
     # We finally build the block graph
     if k == kmax:
         BG = Graph(name = "Random Block Graph with {} blocks of order {}".format(m, k))
@@ -663,7 +659,7 @@ def RandomGNM(n, m, dense=False, seed=None):
         ....:     for m in range(3):
         ....:         n.append(g[3*i + m].plot(vertex_size=50, vertex_labels=False))
         ....:     j.append(n)
-        sage: G = sage.plot.graphics.GraphicsArray(j)
+        sage: G = graphics_array(j)
         sage: G.show()  # long time
     """
     if seed is None:
@@ -731,9 +727,7 @@ def RandomNewmanWattsStrogatz(n, k, p, seed=None):
 
     REFERENCE:
 
-    .. [NWS99] Newman, M.E.J., Watts, D.J. and Strogatz, S.H.  Random
-      graph models of social networks. Proc. Nat. Acad. Sci. USA
-      99, 2566-2572.
+    [NWS2002]_
     """
     if seed is None:
         seed = int(current_randstate().long_seed() % sys.maxsize)
@@ -788,8 +782,7 @@ def RandomHolmeKim(n, m, p, seed=None):
 
     REFERENCE:
 
-    .. [HolmeKim2002] Holme, P. and Kim, B.J. Growing scale-free networks
-      with tunable clustering, Phys. Rev. E (2002). vol 65, no 2, 026107.
+    [HK2002a]_
     """
     if seed is None:
         seed = int(current_randstate().long_seed() % sys.maxsize)
@@ -811,7 +804,7 @@ def RandomIntervalGraph(n):
     being generated from the uniform distribution on the interval
     `[0,1]`.
 
-    This definitions follows [boucheron2001]_.
+    This definitions follows [BF2001]_.
 
     .. NOTE::
 
@@ -832,14 +825,6 @@ def RandomIntervalGraph(n):
         sage: g = graphs.RandomIntervalGraph(8)
         sage: g.clique_number() == g.chromatic_number()
         True
-
-    REFERENCE:
-
-    .. [boucheron2001] Boucheron, S. and FERNANDEZ de la VEGA, W.,
-       On the Independence Number of Random Interval Graphs,
-       Combinatorics, Probability and Computing v10, issue 05,
-       Pages 385--396,
-       Cambridge Univ Press, 2001
     """
 
     from sage.misc.prandom import random
@@ -1434,13 +1419,9 @@ def RandomRegular(d, n, seed=None):
 
     REFERENCES:
 
-    .. [KimVu2003] Kim, Jeong Han and Vu, Van H. Generating random regular
-      graphs. Proc. 35th ACM Symp. on Thy. of Comp. 2003, pp
-      213-222. ACM Press, San Diego, CA, USA.
-      http://doi.acm.org/10.1145/780542.780576
+    - [KV2003]_
 
-    .. [StegerWormald1999] Steger, A. and Wormald, N. Generating random
-      regular graphs quickly. Prob. and Comp. 8 (1999), pp 377-396.
+    - [SW1999]_
     """
     if seed is None:
         seed = int(current_randstate().long_seed() % sys.maxsize)
@@ -1534,119 +1515,125 @@ def RandomToleranceGraph(n):
 
 # uniform random triangulation using Schaeffer-Poulalhon algorithm
 
-
-def _auxiliary_random_word(n):
+def _auxiliary_random_forest_word(n, k):
     r"""
     Return a random word used to generate random triangulations.
 
     INPUT:
 
-    n -- an integer
+    - ``n`` -- an integer
+
+    - ``k`` -- an integer
 
     OUTPUT:
 
-    A binary sequence `w` of length `4n-2` with `n-1` ones, such that any proper
-    prefix `u` of `w` satisfies `3|u|_1 - |u|_0 > -2` (where `|u|_1` and `|u|_0`
-    are respectively the number of 1s and 0s in `u`). Those words are the
-    expected input of :func:`_contour_and_graph_from_word`.
+    A binary sequence `w` of length `4n+2k-4` with `n` ones, such that any
+    proper prefix `u` of `w` satisfies `3|u|_1 - |u|_0 \geq -2k+4` (where
+    `|u|_1` and `|u|_0` are respectively the number of 1s and 0s in `u`). Those
+    words are the expected input of :func:`_contour_and_graph_from_words`.
 
     ALGORITHM:
 
-    A random word with these numbers of `0` and `1` is chosen. This
-    word is then rotated in order to give an admissible code for a
-    tree (as explained in Proposition 4.2, [PS2006]_). There are
-    exactly two such rotations, one of which is chosen at random.
+    A random word with these numbers of `0` and `1` plus one additional `0` is
+    chosen. This word is then rotated such the prefix property is fulfilled for
+    each proper prefix and only violated by the final `0` (which is deleted
+    afterwards). There is exactly one such rotation (compare Section 4.3 in
+    [PS2006]_).
 
     Let us consider a word `w` satisfying the expected conditions. By
-    drawing a step (1,3) for each 1 and a step (1,-1) for each 0 in
-    `w`, one gets a path starting at height 0, ending at height -2 and
-    staying above (or on) the horizontal line of height -1 except at the
-    end point. By cutting the word at the first position of height -1,
-    let us write `w=uv`. One can then see that `v` can only touch the line
-    of height -1 at its initial point and just before its end point
-    (these two points may be the same).
+    drawing a step `(1,3)` for each `1` and a step `(1,-1)` for each `0` in
+    `w`, one gets a path starting at height `0`, ending at height `-2k+3`
+    (before removing the final `0`) and staying above (or on) the horizontal
+    line of height `-2k+4` except at the end point.
 
-    Now consider a word `w'` obtained from `w` by any
-    rotation. Because `vu` is another word satisfying the expected
-    conditions, one can assume that `w'` is obtained from `w` by
-    starting at some point in `u`. The algorithm must then recognize
-    the end of `u` and the end of `v` inside `w'`. The end of `v` is
-    the unique point of minimal height `h`. The end of `u` is the first
-    point reaching the height `h+1`.
+    Now consider an arbitrary word `w` with `n` ones and `3n+2k-3` zeros. By
+    cutting the word at the first position of minimum height, let us write
+    `w=uv`. One can then see that the word `vu` touches the line of height
+    `-2k+3` only after the last step. Further one can see that this is the only
+    rotation of the word `w` with this property.
 
     EXAMPLES::
 
-        sage: from sage.graphs.generators.random import _auxiliary_random_word
-        sage: _auxiliary_random_word(4)  # random
-        [1, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0]
+        sage: from sage.graphs.generators.random import _auxiliary_random_forest_word
+        sage: with(seed(94364165)):
+        ....:     _auxiliary_random_forest_word(4, 3)
+        ....:     _auxiliary_random_forest_word(3, 5)
+        [1, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 0, 0, 0]
+        [1, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]
 
-        sage: def check(w):
+    TESTS::
+
+        sage: def partial_sums(w):
         ....:     steps = {1: 3, 0: -1}
-        ....:     return all(sum(steps[u] for u in w[:i]) >= -1 for i in range(len(w)))
+        ....:     curr_sum = 0
+        ....:     for x in w:
+        ....:         curr_sum += steps[x]
+        ....:         yield curr_sum
 
-        sage: for n in range(1, 10):
-        ....:     w = _auxiliary_random_word(n)
-        ....:     assert len(w) == 4 * n - 2
-        ....:     assert w.count(0) == 3 * n - 1
-        ....:     assert check(w)
+        sage: for k in range(3,6):
+        ....:     for n in range(k, 10):
+        ....:         w = _auxiliary_random_forest_word(n, k)
+        ....:         assert len(w) == 4*n + 2*k - 4
+        ....:         assert w.count(1) == n
+        ....:         for partial_sum in partial_sums(w):
+        ....:             assert partial_sum >= -2*k + 4
     """
     from sage.misc.prandom import shuffle
-    w = [0] * (3 * n - 1) + [1] * (n - 1)
+    w = [0] * (3*n + 2*k - 3) + [1] * n
     shuffle(w)
 
-    # Finding the two admissible shifts.
-    # The 'if height' is true at least once.
-    # If it is true just once, then the word is admissible
-    # and cuts = [0, first position of -1] (ok)
-    # Otherwise, cuts will always contain
-    # [first position of hmin, first position of hmin - 1] (ok)
-    cuts = [0, 0]
-    height = 0
-    height_min = 0
-    for i in range(4 * n - 3):
-        if w[i] == 1:
-            height += 3
+    # Finding the admissible shift
+    partial_sum = 0
+    min_value = 0
+    min_pos = 0
+    for i, x in enumerate(w):
+        if x:
+            partial_sum += 3
         else:
-            height -= 1
-            if height < height_min:
-                height_min = height
-                cuts = cuts[1], i + 1
-
-    # random choice of one of the two possible cuts
-    idx = cuts[randint(0, 1)]
-    return w[idx:] + w[:idx]
+            partial_sum -= 1
+        if partial_sum < min_value:
+            min_value = partial_sum
+            min_pos = i
+    return w[min_pos+1:] + w[:min_pos]
 
 
-def _contour_and_graph_from_word(w):
+def _contour_and_graph_from_words(pendant_word, forest_word):
     r"""
-    Return the contour word and the graph of inner vertices of the tree
-    associated with the word `w`.
+    Return the contour word and the graph of inner vertices of the `k`-gonal
+    forest associated with the words ``pendant_word`` and ``forest_word``.
 
     INPUT:
 
-    - `w` -- a word in `0` and `1` as given by :func:`_auxiliary_random_word`
+    - ``pendant_word`` -- a word with `k-1` zeros and `k-3` ones
 
-    This word must satisfy the conditions described in Proposition 4.2 of
-    [PS2006]_ (see :func:`_auxiliary_random_word`).
+    - ``forest_word`` -- a word in `0` and `1` as given by
+      :func:`_auxiliary_random_word` with the parameter ``k`` set to the number
+      of zeros in ``pendant_word`` plus `1`
+
+    ``forest_word`` must satisfy the conditions hinted in Proposition 5.4 of
+    [PS2006]_ (see :func:`_auxiliary_random_forest_word`).
 
     OUTPUT:
 
     a pair ``(seq, G)`` where:
 
     - ``seq`` is a sequence of pairs (label, integer) representing the
-      contour walk along the tree associated with `w`
+      contour walk along the `k`-gonal forest associated with the words
+      ``pendant_word`` and ``forest_word``.
 
-    - ``G`` is the tree obtained by restriction to the set of inner vertices
+    - ``G`` is the `k`-gonal forest associated with the words ``pendant_word``
+      and ``forest_word``.
 
-    The underlying bijection from words to trees is given by lemma 4.1
-    in [PS2006]_. It maps the admissible words to planar trees where
-    every inner vertex has two leaves.
+    The underlying bijection from words to `k`-gonal forests is described in
+    Section 5.1 of [PS2006]_. The ``pendant_word`` corresponds to the factor
+    `\binom{2k-4}{k-3}` in the counting formula of Proposition 5.4 and the
+    ``forest_word`` corresponds to the factor `\frac{2k-3}{3m+2k-3}
+    \binom{4m+2k-4}{m}`.
 
-    In the word `w`, the letter `1` means going away from the root ("up") from
-    an inner vertex to another inner vertex. The letter `0` denotes all other
-    steps of the discovery, i.e. either discovering a leaf vertex or going
-    toward the root ("down"). Thus, the length of `w` is twice the number of
-    edges between inner vertices, plus the number of leaves.
+    In the ``forest_word``, the letter `1` means going away from the root ("up")
+    from an inner vertex to another inner vertex. The letter `0` denotes all
+    other steps of the discovery, i.e. either discovering a leaf vertex or going
+    toward the root ("down").
 
     Inner vertices are tagged with 'in' and leaves are tagged with
     'lf'. Inner vertices are moreover labelled by integers, and leaves
@@ -1654,102 +1641,150 @@ def _contour_and_graph_from_word(w):
 
     EXAMPLES::
 
-        sage: from sage.graphs.generators.random import _contour_and_graph_from_word
-        sage: seq, G = _contour_and_graph_from_word([1,0,0,0,0,0])
+        sage: from sage.graphs.generators.random import _contour_and_graph_from_words
+        sage: seq, G = _contour_and_graph_from_words([0, 0], [1, 0, 0, 0, 0, 0])
         sage: seq
         [('in', 0),
-         ('in', 1),
-         ('lf', 1),
-         ('in', 1),
-         ('lf', 1),
-         ('in', 1),
+         ('in', 3),
+         ('lf', 3),
+         ('in', 3),
+         ('lf', 3),
+         ('in', 3),
          ('in', 0),
-         ('lf', 0),
-         ('in', 0),
-         ('lf', 0)]
+         ('in', 1),
+         ('in', 2)]
         sage: G
-        Graph on 2 vertices
+        Graph on 4 vertices
 
-        sage: from sage.graphs.generators.random import _auxiliary_random_word
-        sage: seq, G = _contour_and_graph_from_word(_auxiliary_random_word(20))
-        sage: G.is_tree()
-        True
+        sage: from sage.graphs.generators.random import _auxiliary_random_forest_word
+        sage: _, G = _contour_and_graph_from_words([0, 1, 0, 0, 1, 0], _auxiliary_random_forest_word(20, 5)) # random
+        sage: len(G.faces())
+        2
 
         sage: longw = [1,1,0,1,0,0,0,1,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0]
-        sage: seq, G = _contour_and_graph_from_word(longw)
+        sage: _, G = _contour_and_graph_from_words([0, 0], longw)
         sage: G.get_embedding()
-        {0: [1], 1: [0, 2], 2: [1, 3, 4], 3: [2], 4: [2, 5, 6], 5: [4], 6: [4]}
+        {0: [1, 2, 3],
+         1: [2, 0],
+         2: [0, 1],
+         3: [0, 4],
+         4: [3, 5, 6],
+         5: [4],
+         6: [4, 7, 8],
+         7: [6],
+         8: [6]}
     """
-    index       = 0          # numbering of inner vertices
-    word        = [('in', 0)]  # initial vertex is inner
-    leaf_stack  = [0, 0]     # stack of leaves still to be created
-    inner_stack = [0]        # stack of active inner nodes
-    edges = []
-    embedding = {0: []}  # records the planar embedding of the tree
-    for x in w:
-        if x == 1:  # going up to a new inner vertex
-            index += 1
-            embedding[index] = inner_stack[-1:]
-            embedding[inner_stack[-1]].append(index)
-            leaf_stack.extend([index, index])
-            inner_stack.append(index)
-            edges.append(inner_stack[-2:])
-            word.append(('in', index))
+    k = (len(pendant_word)+4) // 2
+
+    index = 0 # numbering of inner vertices
+    word = [('in',0)] # the word representing the contour walk
+
+    # start with the outer face, a cycle of length k
+    edges = [[i, (i+1) % k] for i in range(k)]
+    embedding = {i: [(i+1) % k, (i-1+k) % k] for i in range(k)}
+
+    # add the pendant edges
+    for x in pendant_word:
+        if x:
+            word.extend([('lf', index), ('in', index)])
         else:
-            if leaf_stack and inner_stack[-1] == leaf_stack[-1]:  # up and down to a new leaf
-                leaf_stack.pop()
-                word.extend([('lf', inner_stack[-1]), ('in', inner_stack[-1])])
-            else:  # going down to a known inner vertex
-                inner_stack.pop()
-                word.append(('in', inner_stack[-1]))
+            index += 1
+            word.append(('in', index))
+
+    # add trees
+    curr_word_pos = 0
+    curr_forest_word_pos = 0
+    while curr_forest_word_pos < len(forest_word):
+        x = forest_word[curr_forest_word_pos]
+        # insert a tree at current position
+        if x:
+            index += 1
+            embedding[index] = [word[curr_word_pos][1]]
+            embedding[word[curr_word_pos][1]].append(index)
+            edges.append([word[curr_word_pos][1], index])
+            # stack of leaves still to be created
+            leaf_stack = [index, index]
+            # stack of active inner nodes
+            inner_stack = [word[curr_word_pos][1], index]
+            word.insert(curr_word_pos+1, ('in', index))
+            curr_word_pos += 1
+            while len(inner_stack) > 1:
+                curr_forest_word_pos += 1
+                x = forest_word[curr_forest_word_pos]
+                if x:
+                    index += 1
+                    embedding[index] = inner_stack[-1:]
+                    embedding[inner_stack[-1]].append(index)
+                    leaf_stack.extend([index, index])
+                    inner_stack.append(index)
+                    edges.append(inner_stack[-2:])
+                    word.insert(curr_word_pos+1, ('in', index))
+                    curr_word_pos += 1
+                else:
+                    # up and down to a new leaf
+                    if leaf_stack and inner_stack[-1] == leaf_stack[-1]:
+                        leaf_stack.pop()
+                        word.insert(curr_word_pos+1, ('lf', inner_stack[-1]))
+                        word.insert(curr_word_pos+2, ('in', inner_stack[-1]))
+                        curr_word_pos += 2
+                    # going down to a known inner vertex
+                    else:
+                        inner_stack.pop()
+                        word.insert(curr_word_pos+1, ('in', inner_stack[-1]))
+                        curr_word_pos += 1
+        # go to next insertion position
+        else:
+            curr_word_pos += 1
+            if word[curr_word_pos][0] == 'lf':
+                curr_word_pos += 1
+        curr_forest_word_pos += 1
+
     G = Graph(edges, format='list_of_edges')
     G.set_embedding(embedding)
-    return word[:-1], G
+    return word, G
 
-
-def RandomTriangulation(n, set_position=False):
+def RandomTriangulation(n, set_position=False, k=3):
     r"""
-    Return a random triangulation on `n` vertices.
+    Return a random inner triangulation of an outer face of degree ``k`` with
+    ``n`` vertices in total.
 
-    A triangulation is a planar graph all of whose faces are
-    triangles (3-cycles).
+    An inner triangulation is a plane graph all of whose faces (except the
+    outer/unbounded face) are triangles (3-cycles).
 
     INPUT:
 
-    - `n` -- an integer
+    - ``n`` -- the number of vertices of the graph
 
-    - ``set_position`` -- boolean (default ``False``) if set to ``True``, this
+    - ``k`` -- the size of the outer face
+
+    - ``set_position`` -- boolean (default ``False``); if set to ``True``, this
       will compute coordinates for a planar drawing of the graph.
 
     OUTPUT:
 
-    A random triangulation chosen uniformly among the *rooted* triangulations on
-    `n` vertices. This is a planar graph and comes with a combinatorial
-    embedding.
+    A random graph chosen uniformly among the inner triangulations of a *rooted*
+    `k`-gon with `n` vertices (including the `k` vertices from the outer face).
+    This is a planar graph and comes with a combinatorial embedding. The
+    vertices of the root edge are labelled ``-1`` and ``-2`` and the outer face
+    is the face returned by :meth:`Graph.faces` in which ``-1`` and ``-2`` are
+    consecutive vertices in this order.
 
     Because some triangulations have nontrivial automorphism
-    groups, this may not be equal to the uniform distribution among unrooted
-    triangulations.
+    groups, this may not be equal to the uniform distribution among inner
+    triangulations of unrooted `k`-gons.
 
     ALGORITHM:
 
-    The algorithm is taken from [PS2006]_, section 2.1.
+    The algorithm is taken from [PS2006]_, Section 5.
 
-    Starting from a planar tree (represented by its contour as a
-    sequence of vertices), one first performs local closures, until no
+    Starting from a planar `k`-gonal forest (represented by its contour as a
+    sequence of vertices), one performs local closures, until no
     one is possible. A local closure amounts to replace in the cyclic
-    contour word a sequence ``in1,in2,in3,lf,in3`` by
-    ``in1,in3``. After all local closures are done, one has reached
-    the partial closure, as in [PS2006]_, figure 5 (a).
-
-    Then one has to perform complete closure by adding two more
-    vertices, in order to reach the situation of [PS2006]_, figure 5
-    (b). For this, it is necessary to find inside the final contour
-    one of the two subsequences ``lf,in,lf``.
+    contour word a sequence ``in1, in2, in3, lf, in3`` by
+    ``in1, in3``.
 
     At every step of the algorithm, newly created edges are recorded
     in a graph, which will be returned at the end.
-
     The combinatorial embedding is also computed and recorded in the
     output graph.
 
@@ -1769,35 +1804,46 @@ def RandomTriangulation(n, set_position=False):
         sage: G.plot(vertex_size=0, vertex_labels=False)
         Graphics object consisting of 13 graphics primitives
 
+        sage: H = graphs.RandomTriangulation(7, k=5)
+        sage: sorted(len(f) for f in H.faces())
+        [3, 3, 3, 3, 3, 3, 3, 5]
+
     TESTS::
 
         sage: G.get_embedding() is not None
         True
+
+        sage: graphs.RandomTriangulation(3, k=4)
+        Traceback (most recent call last):
+        ...
+        ValueError: The number 'n' of vertices must be at least the size 'k' of the outer face.
+        sage: graphs.RandomTriangulation(3, k=2)
+        Traceback (most recent call last):
+        ...
+        ValueError: The size 'k' of the outer face must be at least 3.
+
         sage: for i in range(10):
-        ....:     g = graphs.RandomTriangulation(30)
+        ....:     g = graphs.RandomTriangulation(30) # random
         ....:     assert g.is_planar()
-        sage: for i in range(10):
-        ....:     g = graphs.RandomTriangulation(10)
+        sage: for k in range(3, 10):
+        ....:     g = graphs.RandomTriangulation(10, k=k) # random
         ....:     assert g.is_planar(on_embedding=g.get_embedding())
-
-    REFERENCES:
-
-    .. [PS2006] Dominique Poulalhon and Gilles Schaeffer,
-       *Optimal coding and sampling of triangulations*,
-       Algorithmica 46 (2006), no. 3-4, 505-527,
-       http://www.lix.polytechnique.fr/~poulalho/Articles/PoSc_Algorithmica06.pdf
-
     """
-    if n < 3:
-        raise ValueError('only defined for n >= 3')
-    w = _auxiliary_random_word(n - 2)
-    word, graph = _contour_and_graph_from_word(w)
-    edges = []
+    if k < 3:
+        raise ValueError("The size 'k' of the outer face must be at least 3.")
+    if n < k:
+        raise ValueError("The number 'n' of vertices must be at least the size "
+                         "'k' of the outer face.")
 
+    from sage.misc.prandom import shuffle
+    pendant_word = [0] * (k-1) + [1] * (k-3)
+    shuffle(pendant_word)
+    forest_word = _auxiliary_random_forest_word(n-k, k)
+    word, graph = _contour_and_graph_from_words(pendant_word, forest_word)
+    edges = []
     embedding = graph.get_embedding()
 
-    # 'partial closures' described in 2.1 of [PS2006]_.
-    pattern = ['in', 'in', 'in', 'lf', 'in']
+    pattern = ['in', 'in', 'in', 'lf', 'in'] # 'partial closures'
 
     def rotate_word_to_next_occurrence(word):
         """
@@ -1826,56 +1872,12 @@ def RandomTriangulation(n, set_position=False):
             break
 
     graph.add_edges(edges)
-    # This is the end of partial closure.
-
-    # There remains to add two new vertices a and b.
-    a = -1
-    b = -2
-    graph.add_edge((a, b))
-
-    # Every remaining 'lf' vertex is linked either to a or to b.
-    # Switching a/b happens when one meets the sequence 'lf','in','lf'.
-    a_or_b = a
-    embedding[a] = []
-    embedding[b] = []
-    last_lf_occurrence = -42
-    change = {}
-    for x in word:
-        last_lf_occurrence -= 1
-        if x[0] == 'lf':
-            if last_lf_occurrence == -2:
-                change[a_or_b] = x[1]
-                a_or_b = b if a_or_b == a else a
-            graph.add_edge((a_or_b, x[1]))
-            embedding[a_or_b].insert(0, x[1])
-            last_lf_occurrence = 0
-
-    # conjugates the embeddings of a and b
-    # in a way that helps to complete the embedding
-    for a_or_b in [a, b]:
-        emba = embedding[a_or_b]
-        idx = emba.index(change[a_or_b])
-        embedding[a_or_b] = emba[idx:] + emba[:idx]
-    embedding[a].append(b)
-    embedding[b].append(a)
-
-    # completes the embedding by inserting missing half-edges
-    for a_or_b in [a, b]:
-        emb = embedding[a_or_b]
-        for i, v in enumerate(emb[:-1]):
-            if i == 0:
-                embedding[v].insert(embedding[v].index(emb[1]) + 1, a_or_b)
-            else:
-                embedding[v].insert(embedding[v].index(emb[i - 1]), a_or_b)
-
-    assert graph.num_edges() == 3 * (n - 2)
-    assert graph.num_verts() == n
-
     graph.set_embedding(embedding)
-
+    graph.relabel({0: -2, 1: -1})
+    assert graph.num_edges() == 3*n - 3 - k
+    assert graph.num_verts() == n
     if set_position:
         graph.layout(layout="planar", save_pos=True)
-
     return graph
 
 
@@ -1981,7 +1983,7 @@ def RandomBicubicPlanar(n):
 
     a graph with multiple edges (no embedding is provided)
 
-    The algorithm used is described in [Schaeffer99]_. This samples
+    The algorithm used is described in [Sch1999]_. This samples
     a random rooted bipartite cubic map, chosen uniformly at random.
 
     First one creates a random binary tree with `n` vertices. Next one
@@ -2021,11 +2023,6 @@ def RandomBicubicPlanar(n):
         V1 = [v for v in G.vertices() if v[0] != 'n']
         dic = {'red': V0, 'blue': V1}
         sphinx_plot(G.plot(vertex_labels=False,vertex_colors=dic))
-
-    REFERENCES:
-
-    .. [Schaeffer99] Gilles Schaeffer, *Random Sampling of Large Planar Maps and Convex Polyhedra*,
-       Annual ACM Symposium on Theory of Computing (Atlanta, GA, 1999)
     """
     from sage.combinat.binary_tree import BinaryTrees
     from sage.rings.finite_rings.integer_mod_ring import Zmod
