@@ -278,6 +278,8 @@ class GenericGraphQuery(SQLQuery):
            advanced users. It allows you to execute any query, and so may be
            considered unsafe.
 
+        EXAMPLES:
+
         See :class:`~GraphDatabase` class docstrings or enter::
 
             sage: G = GraphDatabase()
@@ -312,6 +314,7 @@ class GenericGraphQuery(SQLQuery):
             raise TypeError('%s is not a valid GraphDatabase'%database)
         SQLQuery.__init__(self, database, query_string, param_tuple)
 
+
 class GraphQuery(GenericGraphQuery):
 
     def __init__(self, graph_db=None, query_dict=None, display_cols=None, **kwds):
@@ -922,18 +925,19 @@ class GraphDatabase(SQLDatabase):
         not be called directly.
         """
         from sagenb.notebook.interact import input_grid
+        function_name = '__temporary_interact_function'
         arg = ['%s=%s'%(word, kwds[word]) for word in kwds]
         boxes = ["%s=input_grid(1,2,['=',%s])"%(word, kwds[word]) for word in kwds]
         params = ['%s=%s[0]'%tuple(2 * [arg[i].split('=')[0]]) for i in range(len(arg))]
 
-        s = 'def _(%s):'%','.join(boxes)
+        s = 'def %s(%s):' % (function_name, ','.join(boxes))
         t = """
         print('<html><h2>Query Results:</h2></html>')
         GraphQuery(display_cols=%s,%s).show(with_picture=True)
         """%tuple([display, ','.join(params)])
         s += '\t' + '\n\t'.join(t.split('\n')) + '\n'
         exec(s)
-        return _
+        return locals()[function_name]
 
     def query(self, query_dict=None, display_cols=None, **kwds):
         """
@@ -1078,8 +1082,13 @@ class GraphDatabase(SQLDatabase):
         EXAMPLES::
 
             sage: D = GraphDatabase()
-            sage: D.interactive_query(display_cols=['graph6', 'num_vertices', 'degree_sequence'], num_edges=5, max_degree=3)
+            sage: D.interactive_query(display_cols=['graph6', 'num_vertices', 'degree_sequence'], num_edges=5, max_degree=3)  # py2
             <html>...</html>
+
+        .. WARNING::
+
+            Above doctest is known to fail with Python 3 due to ``sagenb``. See
+            :trac:`27435` for more details.
         """
         from sagenb.notebook.interact import interact
         print('<html><h1>Interactive Graph Query</h1></html>')
