@@ -1631,7 +1631,7 @@ class GraphLatex(SageObject):
         # Which is just a convenience for forming vertex names internal to
         # tkz-graph
         index_of_vertex = {}
-        vertex_list = self._graph.vertices()
+        vertex_list = self._graph.vertices(sort=False)
         for u in self._graph:
             index_of_vertex[u] = vertex_list.index(u)
 
@@ -1769,7 +1769,7 @@ class GraphLatex(SageObject):
                 el_slope = {}
                 el_placement = {}
 
-            for e in self._graph.edges():
+            for e in self._graph.edges(sort=False):
                 edge = (e[0], e[1])
                 reverse = (e[1], e[0])
                 #
@@ -1946,7 +1946,7 @@ class GraphLatex(SageObject):
         s += ['%\n']
 
         # Create each edge or loop
-        for e in self._graph.edges():
+        for e in self._graph.edges(sort=False):
             edge = (e[0], e[1])
             loop = e[0] == e[1]
             if loop:
