@@ -2,7 +2,7 @@ r"""
 Tutte polynomial
 
 This module implements a deletion-contraction algorithm for computing
-the Tutte polynomial as described in the paper [Gordon10]_.
+the Tutte polynomial as described in the paper [HPR2010]_.
 
 .. csv-table::
     :class: contentstable
@@ -28,13 +28,6 @@ connected components we define the Tutte polynomial of `G` as
 
 where the sum ranges over all induced subgraphs `H` of `G`.
 
-REFERENCES:
-
-.. [Gordon10] Computing Tutte Polynomials. Gary Haggard, David
-   J. Pearce and Gordon Royle. In ACM Transactions on Mathematical
-   Software, Volume 37(3), article 24, 2010. Preprint:
-   http://homepages.ecs.vuw.ac.nz/~djp/files/TOMS10.pdf
-
 Functions
 ---------
 """
@@ -232,7 +225,7 @@ class Ear(object):
     r"""
     An ear is a sequence of vertices
 
-    Here is the definition from [Gordon10]_:
+    Here is the definition from [HPR2010]_:
 
     An ear in a graph is a path `v_1 - v_2 - \dots - v_n - v_{n+1}`
     where `d(v_1) > 2`, `d(v_{n+1}) > 2` and
