@@ -182,7 +182,7 @@ from six import string_types
 from .expect import Expect, ExpectElement, FunctionElement, ExpectFunction
 from .gap_workspace import gap_workspace_file, prepare_workspace_dir
 from sage.cpython.string import bytes_to_str
-from sage.env import SAGE_LOCAL, SAGE_EXTCODE
+from sage.env import SAGE_EXTCODE
 from sage.misc.misc import is_in_string
 from sage.misc.cachefunc import cached_method
 from sage.docs.instancedoc import instancedoc
@@ -561,6 +561,14 @@ class Gap_generic(ExtraTabCompletion, Expect):
             'Hi how are you?'
             sage: gap.eval('fi')
             ''
+
+        TESTS:
+
+        Whitespace is not stripped from the front of the result
+        (:trac:`28439`)::
+
+            sage: gap.eval(r'Print("  -\n\\\\-  ")')
+            '  -\n\\\\-'
         """
         # '"
         #We remove all of the comments:  On each line, we try
@@ -583,7 +591,7 @@ class Gap_generic(ExtraTabCompletion, Expect):
         result = Expect.eval(self, input_line, **kwds)
         if not newlines:
             result = result.replace("\\\n","")
-        return result.strip()
+        return result.rstrip()
 
 
     def _execute_line(self, line, wait_for_prompt=True, expect_eof=False):
@@ -666,7 +674,7 @@ class Gap_generic(ExtraTabCompletion, Expect):
             2
             sage: try:
             ....:     alarm(0.5)
-            ....:     while True: SymmetricGroup(7).conjugacy_classes_subgroups()
+            ....:     gap.eval('while(1=1) do i:=1;; od;', wait_for_prompt=True)
             ....: except KeyboardInterrupt:
             ....:     pass
             sage: gap(2)
@@ -735,18 +743,16 @@ class Gap_generic(ExtraTabCompletion, Expect):
             sage: a
             3
         """
-        #if line.find('\n') != -1:
-        #    raise ValueError, "line must not contain any newlines"
-        E = None
+        expect_eof = self._quit_string() in line
+
         try:
             if self._expect is None:
                 self._start()
-            E = self._expect
-            #import pdb; pdb.set_trace()
             if allow_use_file and wait_for_prompt and len(line) > self._eval_using_file_cutoff:
                 return self._eval_line_using_file(line)
+
             (normal, error) = self._execute_line(line, wait_for_prompt=wait_for_prompt,
-                                                 expect_eof= (self._quit_string() in line))
+                                                 expect_eof=expect_eof)
 
             # The internal method _execute_line returns bytes but the bytes it
             # returns should contain text (any terminal commands and other
@@ -777,8 +783,15 @@ class Gap_generic(ExtraTabCompletion, Expect):
                 out = out[:-1]
             return out
 
-        except (RuntimeError,TypeError) as message:
-            if 'EOF' in message.args[0] or E is None or not E.isalive():
+        except (RuntimeError, TypeError, pexpect.ExceptionPexpect) as exc:
+            if not self._isalive():
+                # We can't distinguish just EOF from an unexpectedly killed
+                # process because pexpect catches EOF's and re-reraises them
+                # But if we *were* expecting EOF then we should just let it
+                # fail silently and return
+                if expect_eof:
+                    return ''
+
                 print("** %s crashed or quit executing '%s' **" % (self, line))
                 print("Restarting %s and trying again" % self)
                 self._start()
@@ -787,7 +800,7 @@ class Gap_generic(ExtraTabCompletion, Expect):
                 else:
                     return ''
             else:
-                raise RuntimeError(message)
+                raise RuntimeError(exc)
 
         except KeyboardInterrupt:
             self._keyboard_interrupt()
