@@ -5,8 +5,8 @@ Interface to Macaulay2
 
     You must have ``Macaulay2`` installed on your computer
     for this interface to work. Macaulay2 is not included with Sage,
-    but you can obtain it from <http://www.math.uiuc.edu/Macaulay2/>.
-    Note additional optional Sage packages are required.
+    but you can obtain it from https://faculty.math.illinois.edu/Macaulay2/.
+    No additional optional Sage packages are required.
 
 Sage provides an interface to the Macaulay2 computational algebra
 system. This system provides extensive functionality for commutative
@@ -14,20 +14,20 @@ algebra. You do not have to install any optional packages.
 
 The Macaulay2 interface offers three pieces of functionality:
 
-- ``Macaulay2_console()`` -- A function that dumps you
+- ``macaulay2_console()`` -- A function that dumps you
   into an interactive command-line Macaulay2 session.
 
-- ``Macaulay2(expr)`` -- Evaluation of arbitrary Macaulay2
+- ``macaulay2.eval(expr)`` -- Evaluation of arbitrary Macaulay2
   expressions, with the result returned as a string.
 
-- ``Macaulay2.new(expr)`` -- Creation of a Sage object that wraps a
+- ``macaulay2(expr)`` -- Creation of a Sage object that wraps a
   Macaulay2 object.  This provides a Pythonic interface to Macaulay2.  For
-  example, if ``f=Macaulay2.new(10)``, then ``f.gcd(25)`` returns the
+  example, if ``f = macaulay2(10)``, then ``f.gcd(25)`` returns the
   GCD of `10` and `25` computed using Macaulay2.
 
 EXAMPLES::
 
-    sage: print(macaulay2('3/5 + 7/11')) # optional - macaulay2
+    sage: macaulay2('3/5 + 7/11')       # optional - macaulay2
     68
     --
     55
@@ -38,22 +38,29 @@ EXAMPLES::
     125
 
     sage: R = macaulay2('ZZ/5[x,y,z]')  # optional - macaulay2
-    sage: print(R)                       # optional - macaulay2
+    sage: R                             # optional - macaulay2
     ZZ
-    --[x..z, Degrees => {3:1}, Heft => {1}, MonomialOrder => {MonomialSize => 32}, DegreeRank => 1]
-     5                                                       {GRevLex => {3:1}  }
-                                                             {Position => Up    }
+    --[x, y, z]
+     5
     sage: x = macaulay2('x')            # optional - macaulay2
     sage: y = macaulay2('y')            # optional - macaulay2
-    sage: print((x+y)^5)                # optional - macaulay2
+    sage: (x+y)^5                       # optional - macaulay2
      5    5
     x  + y
     sage: parent((x+y)^5)               # optional - macaulay2
     Macaulay2
 
-    sage: R = macaulay2('QQ[x,y,z,w]')  # optional - macaulay2
-    sage: f = macaulay2('x^4 + 2*x*y^3 + x*y^2*w + x*y*z*w + x*y*w^2 + 2*x*z*w^2 + y^4 + y^3*w + 2*y^2*z*w + z^4 + w^4') # optional - macaulay2
-    sage: print(f)                      # optional - macaulay2
+The name of the variable to which a Macaulay2 element is assigned internally
+can be passed as an argument. This is useful for types like polynomial rings
+which acquire that name in Macaulay2::
+
+    sage: R = macaulay2('QQ[x,y,z,w]', 'R')  # optional - macaulay2
+    sage: R                                  # optional - macaulay2
+    R
+
+    sage: f = macaulay2('x^4 + 2*x*y^3 + x*y^2*w + x*y*z*w + x*y*w^2'    # optional - macaulay2
+    ....:               '+ 2*x*z*w^2 + y^4 + y^3*w + 2*y^2*z*w + z^4 + w^4')
+    sage: f                             # optional - macaulay2
      4       3    4    4      2     3                2           2         2    4
     x  + 2x*y  + y  + z  + x*y w + y w + x*y*z*w + 2y z*w + x*y*w  + 2x*z*w  + w
     sage: g = f * macaulay2('x+y^5')    # optional - macaulay2
@@ -61,6 +68,20 @@ EXAMPLES::
       4       3    4    4      2     3                2           2         2    4   5
     (x  + 2x*y  + y  + z  + x*y w + y w + x*y*z*w + 2y z*w + x*y*w  + 2x*z*w  + w )(y  + x)
 
+Use :meth:`eval` for explicit control over what is sent to the interpreter.
+The argument is evaluated in Macaulay2 as is::
+
+    sage: macaulay2.eval('compactMatrixForm')           # optional - macaulay2
+    true
+    sage: macaulay2.eval('compactMatrixForm = false;')  # optional - macaulay2
+    sage: macaulay2.eval('matrix {{1, x^2+y}}')         # optional - macaulay2
+    |     2     |
+    | 1  x  + y |
+    <BLANKLINE>
+            1       2
+    Matrix R  <--- R
+    sage: macaulay2.eval('compactMatrixForm = true;')   # optional - macaulay2
+
 
 AUTHORS:
 
@@ -79,7 +100,7 @@ AUTHORS:
     Get rid of all numbers in output, e.g., in ideal function below.
 """
 
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2006 Kiran S. Kedlaya <kedlaya@mit.edu>
 #                          David Roe <roed@mit.edu>
 #                          William Stein <wstein@gmail.com>
@@ -93,9 +114,10 @@ AUTHORS:
 #
 #  The full text of the GPL is available at:
 #
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 from __future__ import print_function
+from six import string_types
 
 import os
 import re
@@ -105,6 +127,7 @@ from sage.interfaces.interface import AsciiArtString
 from sage.misc.multireplace import multiple_replace
 from sage.interfaces.tab_completion import ExtraTabCompletion
 from sage.docs.instancedoc import instancedoc
+from sage.cpython.string import bytes_to_str
 
 
 def remove_output_labels(s):
@@ -139,7 +162,7 @@ def remove_output_labels(s):
     label = re.compile("^o[0-9]+ (=|:) |^ *")
     lines = s.split("\n")
     matches = [label.match(l) for l in lines if l != ""]
-    if len(matches) == 0:
+    if not matches:
         return s
     else:
         n = min(m.end() - m.start() for m in matches)
@@ -182,7 +205,10 @@ class Macaulay2(ExtraTabCompletion, Expect):
             # Also prevent line wrapping in Macaulay2
             "printWidth = 0;" +
             # And make all output labels to be of the same width
-            "lineNumber = 10^9;")
+            "lineNumber = 10^9;"
+            # Assignment of internal expect variables.
+            'sageAssign = (k, v) -> (if not instance(v, Sequence) then use v; k <- v);'
+            )
         Expect.__init__(self,
                         name = 'macaulay2',
                         prompt = PROMPT,
@@ -293,32 +319,135 @@ class Macaulay2(ExtraTabCompletion, Expect):
         # parasitic output
         self.eval("restart")
 
+    def set_seed(self, seed=None):
+        r"""
+        Set the seed for Macaulay2 interpreter.
+
+        INPUT:
+
+        - ``seed`` -- number (default: ``None``). If ``None``, it
+          is set to a random number.
+
+        OUTPUT: the new seed
+
+        EXAMPLES::
+
+            sage: m = Macaulay2()                     # optional - macaulay2
+            sage: m.set_seed(123456)                  # optional - macaulay2
+            123456
+            sage: [m.random(100) for _ in range(11)]  # optional - macaulay2
+            [8, 29, 5, 22, 4, 32, 35, 57, 3, 95, 36]
+        """
+        if seed is None:
+            seed = self.rand_seed()
+        self.eval('setRandomSeed(%d)' % seed)
+        self._seed = seed
+        return seed
+
     def get(self, var):
         """
-        Get the value of the variable var.
+        Get the value of the variable ``var``.
+
+        INPUT:
+
+        - ``var`` - string; the name of the variable in Macaulay2
+
+        OUTPUT: a string of the textual representation of the variable in
+        Macaulay2
 
         EXAMPLES::
 
             sage: macaulay2.set("a", "2") # optional - macaulay2
             sage: macaulay2.get("a")      # optional - macaulay2
             2
+
+        Note that the following syntax is used to obtain a
+        ``Macaulay2Element`` instead::
+
+            sage: a = macaulay2('2'); a   # optional - macaulay2
+            2
+            sage: type(a)                 # optional - macaulay2
+            <class 'sage.interfaces.macaulay2.Macaulay2Element'>
         """
-        return self.eval("describe %s"%var, strip=True)
+        return self.eval('print(%s)' % var, strip=False)
 
     def set(self, var, value):
         """
-        Set the variable var to the given value.
+        Set the variable ``var`` to the given value.
+
+        INPUT:
+
+        - ``var`` - string; the name of the variable in Macaulay2
+        - ``value`` - a string to evaluate
 
         EXAMPLES::
 
-            sage: macaulay2.set("a", "2")  # optional - macaulay2
-            sage: macaulay2.get("a")       # optional - macaulay2
+            sage: macaulay2.set("a", "1+1")  # optional - macaulay2
+            sage: macaulay2.get("a")         # optional - macaulay2
             2
+
+        TESTS:
+
+        Check that internal expect variables do not acquire their global
+        variable name and that ``use`` is invoked (:trac:`28303`)::
+
+            sage: R = macaulay2('QQ[x, y]')  # indirect doctest, optional - macaulay2
+            sage: R.net()                    # optional - macaulay2
+            QQ[x, y]
+            sage: S = R / macaulay2('ideal {x^2 - y}')         # optional - macaulay2
+            sage: macaulay2.eval('class x === %s' % S.name())  # optional - macaulay2
+            true
         """
-        cmd = '%s=%s;'%(var,value)
-        ans = Expect.eval(self, cmd)
+        if re.match(r'sage\d+$', var):
+            cmd = 'sageAssign(symbol %s,(%s));' % (var, value)
+        else:
+            cmd = '%s=(%s);' % (var,value)
+        ans = Expect.eval(self, cmd, strip=False)
         if ans.find("stdio:") != -1:
-            raise RuntimeError("Error evaluating Macaulay2 code.\nIN:%s\nOUT:%s"%(cmd, ans))
+            raise RuntimeError("Error evaluating Macaulay2 code.\nIN:%s\nOUT:%s" % (cmd, ans))
+
+    def clear(self, var):
+        """
+        Clear the variable named ``var``.
+
+        The interface automatically clears Macaulay2 elements when they fall
+        out of use, so calling this method is usually not necessary.
+
+        EXAMPLES::
+
+            sage: macaulay2.eval('R = QQ[x,y];')  # optional - macaulay2
+            sage: macaulay2.eval('net class R')   # optional - macaulay2
+            PolynomialRing
+            sage: macaulay2.clear('R')            # optional - macaulay2
+            sage: macaulay2.eval('net class R')   # optional - macaulay2
+            Symbol
+
+        TESTS:
+
+        Check that only internal variables get reused by the interface::
+
+            sage: all(s.startswith('sage') for s in macaulay2._available_vars)  # optional - macaulay2
+            True
+        """
+        if re.match(r'sage\d+$', var):
+            self._available_vars.append(var)
+        else:
+            # this approach is also used by Macaulay2 itself in clearAll
+            cmd = 'globalAssign(symbol {0},symbol {0});'.format(var)
+            Expect.eval(self, cmd, strip=False)
+
+    def _contains(self, v1, v2):
+        """
+        EXAMPLES::
+
+            sage: a = macaulay2([3,4,5])  # optional - macaulay2
+            sage: 0 in a, 2 in a, 3 in a  # optional - macaulay2, indirect doctest
+            (True, True, False)
+            sage: b = macaulay2('hashTable {"x" => 1, "y" => 2}')  # optional - macaulay2
+            sage: 'x' in b, '"x"' in b    # optional - macaulay2, indirect doctest
+            (False, True)
+        """
+        return self.eval("%s#?%s" % (v2, v1)) == self._true_symbol()
 
     def _object_class(self):
         """
@@ -411,7 +540,7 @@ class Macaulay2(ExtraTabCompletion, Expect):
             sage: macaulay2.cputime()       # optional - macaulay2; random
             0.48393700000000001
         """
-        _t = float(self.cpuTime().to_sage())
+        _t = float(self.cpuTime()._sage_())
         if t:
             return _t - t
         else:
@@ -449,9 +578,7 @@ class Macaulay2(ExtraTabCompletion, Expect):
         EXAMPLES::
 
             sage: R2 = macaulay2.ring('QQ', '[x, y]'); R2            # optional - macaulay2
-            QQ[x..y, Degrees => {2:1}, Heft => {1}, MonomialOrder => {MonomialSize => 16}, DegreeRank => 1]
-                                                                     {Lex => 2          }
-                                                                     {Position => Up    }
+            QQ[x, y]
             sage: I = macaulay2.ideal( ('y^2 - x^3', 'x - y') ); I   # optional - macaulay2
                       3    2
             ideal (- x  + y , x - y)
@@ -491,26 +618,35 @@ class Macaulay2(ExtraTabCompletion, Expect):
         This is a ring in variables named a through d over the finite field
         of order 7, with graded reverse lex ordering::
 
-            sage: R1 = macaulay2.ring('ZZ/7', '[a..d]', 'GRevLex');  R1  # optional - macaulay2
+            sage: R1 = macaulay2.ring('ZZ/7', '[a..d]', 'GRevLex')  # optional - macaulay2
+            sage: R1.describe()  # optional - macaulay2
             ZZ
-            --[a..d, Degrees => {4:1}, Heft => {1}, MonomialOrder => {MonomialSize => 16}, DegreeRank => 1]
+            --[a..d, Degrees => {4:1}, Heft => {1}, MonomialOrder => {MonomialSize => 16},
              7                                                       {GRevLex => {4:1}  }
                                                                      {Position => Up    }
-            sage: R1.char()                                             # optional - macaulay2
+            --------------------------------------------------------------------------------
+            DegreeRank => 1]
+            sage: R1.char()  # optional - macaulay2
             7
 
         This is a polynomial ring over the rational numbers::
 
-            sage: R2 = macaulay2.ring('QQ', '[x, y]'); R2               # optional - macaulay2
-            QQ[x..y, Degrees => {2:1}, Heft => {1}, MonomialOrder => {MonomialSize => 16}, DegreeRank => 1]
+            sage: R2 = macaulay2.ring('QQ', '[x, y]')  # optional - macaulay2
+            sage: R2.describe()  # optional - macaulay2
+            QQ[x..y, Degrees => {2:1}, Heft => {1}, MonomialOrder => {MonomialSize => 16},
                                                                      {Lex => 2          }
                                                                      {Position => Up    }
+            --------------------------------------------------------------------------------
+            DegreeRank => 1]
+
+        TESTS::
+
+            sage: macaulay2.ring('QQ', '[a_0..a_2,b..<d,f]').vars()     # optional - macaulay2
+            | a_0 a_1 a_2 b c f |
         """
         varstr = str(vars)[1:-1]
-        if ".." in varstr:
-            varstr = "symbol " + varstr[0] + ".." + "symbol " + varstr[-1]
-        else:
-            varstr = ", ".join(["symbol " + v for v in varstr.split(", ")])
+        r = re.compile(r"(?<=,)|(?<=\.\.<)|(?<=\.\.)(?!<)")
+        varstr = "symbol " + r.sub("symbol ", varstr)
         return self.new('%s[%s, MonomialSize=>16, MonomialOrder=>%s]'%(base_ring, varstr, order))
 
     def help(self, s):
@@ -518,7 +654,7 @@ class Macaulay2(ExtraTabCompletion, Expect):
         EXAMPLES::
 
             sage: macaulay2.help("load")  # optional - macaulay2
-            load ...
+            load...
             ****...
             ...
               * "input" -- read Macaulay2 commands and echo
@@ -553,7 +689,7 @@ class Macaulay2(ExtraTabCompletion, Expect):
         # o1, o2, etc. and automatic Sage variable names sage0, sage1, etc.
         # It is faster to get it back as a string.
         r = macaulay2.eval(r"""
-            toString select(
+            print toString select(
                 apply(apropos "^[[:alnum:]]+$", toString),
                 s -> not match("^(o|sage)[0-9]+$", s))
             """)
@@ -570,19 +706,14 @@ class Macaulay2(ExtraTabCompletion, Expect):
 
             sage: R = macaulay2("QQ[x,y]")                  # optional - macaulay2
             sage: P = macaulay2("ZZ/7[symbol x, symbol y]") # optional - macaulay2
-            sage: macaulay2("x").cls()                      # optional - macaulay2
-            ZZ
-            --[x..y, Degrees => {2:1}, Heft => {1}, MonomialOrder => {MonomialSize => 32}, DegreeRank => 1]
-             7                                                       {GRevLex => {2:1}  }
-                                                                     {Position => Up    }
+            sage: macaulay2("x").cls()._operator('===', P)  # optional - macaulay2
+            true
             sage: macaulay2.use(R)                          # optional - macaulay2
-            sage: macaulay2("x").cls()                      # optional - macaulay2
-            QQ[x..y, Degrees => {2:1}, Heft => {1}, MonomialOrder => {MonomialSize => 32}, DegreeRank => 1]
-                                                                     {GRevLex => {2:1}  }
-                                                                     {Position => Up    }
+            sage: macaulay2("x").cls()._operator('===', R)  # optional - macaulay2
+            true
         """
         R = self(R)
-        self.eval("use %s"%R.name())
+        self.eval("use %s;" % R.name(), strip=False)
 
     def new_from(self, type, value):
         """
@@ -605,6 +736,14 @@ class Macaulay2(ExtraTabCompletion, Expect):
 
 @instancedoc
 class Macaulay2Element(ExtraTabCompletion, ExpectElement):
+    """
+    Instances of this class represent objects in Macaulay2.
+
+    Using the method :meth:`sage` we can translate some of them to
+    SageMath objects:
+
+    .. automethod:: _sage_
+    """
     def _latex_(self):
         r"""
         EXAMPLES::
@@ -614,7 +753,7 @@ class Macaulay2Element(ExtraTabCompletion, ExpectElement):
             | 1 2 |
             | 3 4 |
             sage: latex(m) # optional - macaulay2
-            \begin{pmatrix}1& 2\\ 3& 4\\ \end{pmatrix}
+            \begin{pmatrix}...1...2...3...4...\end{pmatrix}
         """
         s = self.tex().external_string().strip('"').strip('$').replace('\\\\','\\')
         s = s.replace(r"\bgroup","").replace(r"\egroup","")
@@ -638,13 +777,11 @@ class Macaulay2Element(ExtraTabCompletion, ExpectElement):
             sage: R = macaulay2("QQ[x,y,z]/(x^3-y^3-z^3)") # optional - macaulay2
             sage: x = macaulay2('x')                       # optional - macaulay2
             sage: y = macaulay2('y')                       # optional - macaulay2
-            sage: print(x+y)                               # optional - macaulay2
+            sage: str(x+y)                                 # optional - macaulay2
             x + y
-            sage: print(macaulay2("QQ[x,y,z]"))            # optional - macaulay2
-            QQ[x..z, Degrees => {3:1}, Heft => {1}, MonomialOrder => {MonomialSize => 32}, DegreeRank => 1]
-                                                                     {GRevLex => {3:1}  }
-                                                                     {Position => Up    }
-            sage: print(macaulay2("QQ[x,y,z]/(x+y+z)"))    # optional - macaulay2
+            sage: str(macaulay2("QQ[x,y,z]"))              # optional - macaulay2
+            QQ[x, y, z]
+            sage: str(macaulay2("QQ[x,y,z]/(x+y+z)"))      # optional - macaulay2
             QQ[x, y, z]
             -----------
              x + y + z
@@ -652,7 +789,22 @@ class Macaulay2Element(ExtraTabCompletion, ExpectElement):
         P = self._check_valid()
         return P.get(self._name)
 
-    repr = __str__
+    def _repr_(self):
+        """
+        EXAMPLES::
+
+            sage: repr(macaulay2('1..25'))  # optional - macaulay2
+            (1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22,
+            --------------------------------------------------------------------------------
+            23, 24, 25)
+            sage: str(macaulay2('1..25'))  # optional - macaulay2
+            (1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25)
+        """
+        from sage.typeset.ascii_art import empty_ascii_art
+        P = self.parent()
+        return P.eval('print(wrap(%d,"-",net %s))'
+                      % (empty_ascii_art._terminal_width(), self._name),
+                      strip=False)
 
     def external_string(self):
         """
@@ -674,6 +826,61 @@ class Macaulay2Element(ExtraTabCompletion, ExpectElement):
         s = multiple_replace({'\r':'', '\n':' '}, X)
         return s
 
+    def name(self, new_name=None):
+        """
+        Get or change the name of this Macaulay2 element.
+
+        INPUT:
+
+        - ``new_name`` -- string (default: ``None``). If ``None``, return the
+          name of this element; else return a new object identical to ``self``
+          whose name is ``new_name``.
+
+        Note that this can overwrite existing variables in the system.
+
+        EXAMPLES::
+
+            sage: S = macaulay2(QQ['x,y'])          # optional - macaulay2
+            sage: S.name()                          # optional - macaulay2
+            'sage...'
+            sage: R = S.name("R")                   # optional - macaulay2
+            sage: R.name()                          # optional - macaulay2
+            'R'
+            sage: R.vars().cokernel().resolution()  # optional - macaulay2
+             1      2      1
+            R  <-- R  <-- R  <-- 0
+            <BLANKLINE>
+            0      1      2      3
+
+        The name can also be given at definition::
+
+            sage: A = macaulay2(ZZ['x,y,z'], name='A')  # optional - macaulay2
+            sage: A.name()                              # optional - macaulay2
+            'A'
+            sage: A^1                                   # optional - macaulay2
+             1
+            A
+        """
+        if new_name is None:
+            return self._name
+        if not isinstance(new_name, string_types):
+            raise TypeError("new_name must be a string")
+
+        P = self.parent()
+        # First release self, so that new_name becomes the initial reference to
+        # its value.  This is needed to change the name of a PolynomialRing.
+        # NOTE: This does not work if self._name is not the initial reference.
+        cmd = """(() -> (
+            m := lookup(GlobalReleaseHook, class {0});
+            if m =!= null then m(symbol {0}, {0});
+            {1} = {0};
+            ))()""".format(self._name, new_name)
+        ans = P.eval(cmd)
+        if ans.find("stdio:") != -1:
+            raise RuntimeError("Error evaluating Macaulay2 code.\n"
+                               "IN:%s\nOUT:%s" % (cmd, ans))
+        return P._object_class()(P, new_name, is_name=True)
+
     def __len__(self):
         """
         EXAMPLES::
@@ -742,20 +949,12 @@ class Macaulay2Element(ExtraTabCompletion, ExpectElement):
 
         Now make the M2 version of R, so we can coerce elements of R to M2::
 
-            sage: macaulay2(R)                           # optional - macaulay2
-            ZZ
-            --[x..y, Degrees => {2:1}, Heft => {1}, MonomialOrder => {MonomialSize => 16}, DegreeRank => 1]
-             7                                                       {GRevLex => {2:1}  }
-                                                                     {Position => Up    }
-            sage: f = (x^3 + 2*y^2*x)^7; f
-            x^21 + 2*x^7*y^14
-            sage: h = macaulay2(f); h                    # optional - macaulay2
+            sage: _ = macaulay2(R)                       # optional - macaulay2
+            sage: h = macaulay2((x^3 + 2*y^2*x)^7); h    # optional - macaulay2
              21     7 14
             x   + 2x y
-            sage: f1 = (x^2 + 2*y*x)                     # optional - macaulay2
-            sage: h1 = macaulay2(f1)                     # optional - macaulay2
-            sage: f2 = (x^3 + 2*y*x)                     # optional - macaulay2
-            sage: h2 = macaulay2(f2)                     # optional - macaulay2
+            sage: h1 = macaulay2(x^2 + 2*y*x)            # optional - macaulay2
+            sage: h2 = macaulay2(x^3 + 2*y*x)            # optional - macaulay2
             sage: u = h // [h1,h2]                       # optional - macaulay2
             sage: h == u[0]*h1 + u[1]*h2 + (h % [h1,h2]) # optional - macaulay2
             True
@@ -777,20 +976,12 @@ class Macaulay2Element(ExtraTabCompletion, ExpectElement):
 
         Now make the M2 version of R, so we can coerce elements of R to M2::
 
-            sage: macaulay2(R)                              # optional - macaulay2
-            ZZ
-            --[x..y, Degrees => {2:1}, Heft => {1}, MonomialOrder => {MonomialSize => 16}, DegreeRank => 1]
-             7                                                       {GRevLex => {2:1}  }
-                                                                     {Position => Up    }
-            sage: f = (x^3 + 2*y^2*x)^7; f                  # optional - macaulay2
-            x^21 + 2*x^7*y^14
-            sage: h = macaulay2(f); print(h)                # optional - macaulay2
+            sage: _ = macaulay2(R)                          # optional - macaulay2
+            sage: h = macaulay2((x^3 + 2*y^2*x)^7); h       # optional - macaulay2
              21     7 14
             x   + 2x y
-            sage: f1 = (x^2 + 2*y*x)                        # optional - macaulay2
-            sage: h1 = macaulay2(f1)                        # optional - macaulay2
-            sage: f2 = (x^3 + 2*y*x)                        # optional - macaulay2
-            sage: h2 = macaulay2(f2)                        # optional - macaulay2
+            sage: h1 = macaulay2(x^2 + 2*y*x)               # optional - macaulay2
+            sage: h2 = macaulay2(x^3 + 2*y*x)               # optional - macaulay2
             sage: h % [h1,h2]                               # optional - macaulay2
             -3x*y
             sage: u = h // [h1,h2]                          # optional - macaulay2
@@ -844,12 +1035,19 @@ class Macaulay2Element(ExtraTabCompletion, ExpectElement):
         EXAMPLES::
 
             sage: S = macaulay2('QQ[a..d]')                     # optional - macaulay2
-            sage: R = S/macaulay2('a^3+b^3+c^3+d^3')            # optional - macaulay2
-            sage: X = R.Proj()                                  # optional - macaulay2
-            sage: print(X.structure_sheaf())                    # optional - macaulay2
+            sage: R = S / macaulay2('a^3 + b^3 + c^3 + d^3')    # optional - macaulay2
+            sage: X = R.Proj().name('X')                        # optional - macaulay2
+            sage: X.structure_sheaf()                           # optional - macaulay2
+            doctest:...: DeprecationWarning: The function `structure_sheaf` is deprecated. Use `self.sheaf()` instead.
+            See https://trac.sagemath.org/27848 for details.
             OO
-              sage...
+              X
+            sage: X.sheaf()                                     # optional - macaulay2
+            OO
+              X
         """
+        from sage.misc.superseded import deprecation
+        deprecation(27848, 'The function `structure_sheaf` is deprecated. Use `self.sheaf()` instead.')
         return self.parent()('OO_%s'%self.name())
 
     def substitute(self, *args, **kwds):
@@ -864,7 +1062,7 @@ class Macaulay2Element(ExtraTabCompletion, ExpectElement):
             sage: x, = R.gens()                     # optional - macaulay2
             sage: a = x^2 + 1                       # optional - macaulay2
             sage: a = a.substitute(P)               # optional - macaulay2
-            sage: a.to_sage().parent()              # optional - macaulay2
+            sage: a.sage().parent()                 # optional - macaulay2
             Univariate Polynomial Ring in x over Finite Field of size 7
 
         """
@@ -884,20 +1082,27 @@ class Macaulay2Element(ExtraTabCompletion, ExpectElement):
 
         TESTS::
 
-            sage: a = macaulay2("QQ[x,y]")   # optional - macaulay2
-            sage: traits = a._tab_completion()   # optional - macaulay2
-            sage: "generators" in traits     # optional - macaulay2
+            sage: a = macaulay2("QQ[x,y]")      # optional - macaulay2
+            sage: traits = a._tab_completion()  # optional - macaulay2
+            sage: "generators" in traits        # optional - macaulay2
             True
+
+        The implementation of this function does not set or change global
+        variables::
+
+            sage: a.dictionary()._operator('#?', '"r"')  # optional - macaulay2
+            false
         """
         # It is possible, that these are not all possible methods, but
         # there are still plenty and at least there are no definitely
         # wrong ones...
         r = self.parent().eval(
-            """currentClass = class %s;
-            total = {};
+            """(() -> (
+            currentClass := class %s;
+            total := {};
             while true do (
                 -- Select methods with first argument of the given class
-                r = select(methods currentClass, s -> s_1 === currentClass);
+                r := select(methods currentClass, s -> s_1 === currentClass);
                 -- Get their names as strings
                 r = apply(r, s -> toString s_0);
                 -- Keep only alpha-numeric ones
@@ -906,8 +1111,9 @@ class Macaulay2Element(ExtraTabCompletion, ExpectElement):
                 total = total | select(r, s -> not any(total, e -> e == s));
                 if parent currentClass === currentClass then break;
                 currentClass = parent currentClass;
-                )
-            print toString total""" % self.name())
+                );
+            print toString total
+            ))()""" % self.name())
         r = sorted(r[1:-1].split(", "))
         return r
 
@@ -939,7 +1145,7 @@ class Macaulay2Element(ExtraTabCompletion, ExpectElement):
         """
         parent = self.parent()
         x = parent(x)
-        return parent("%s.%s"%(self.name(), x))
+        return parent("%s.%s" % (self.name(), x))
 
     def _operator(self, opstr, x):
         """
@@ -995,67 +1201,73 @@ class Macaulay2Element(ExtraTabCompletion, ExpectElement):
     ####################
     #Conversion to Sage#
     ####################
-    def to_sage(self):
+    def _sage_(self):
         """
         EXAMPLES::
 
-            sage: macaulay2(ZZ).to_sage()      # optional - macaulay2
+            sage: macaulay2(ZZ).sage()         # optional - macaulay2, indirect doctest
             Integer Ring
-            sage: macaulay2(QQ).to_sage()      # optional - macaulay2
+            sage: macaulay2(QQ).sage()         # optional - macaulay2
             Rational Field
 
-            sage: macaulay2(2).to_sage()       # optional - macaulay2
+            sage: macaulay2(2).sage()          # optional - macaulay2
             2
-            sage: macaulay2(1/2).to_sage()     # optional - macaulay2
+            sage: macaulay2(1/2).sage()        # optional - macaulay2
             1/2
-            sage: macaulay2(2/1).to_sage()     # optional - macaulay2
+            sage: macaulay2(2/1).sage()        # optional - macaulay2
             2
             sage: _.parent()                   # optional - macaulay2
             Rational Field
-            sage: macaulay2([1,2,3]).to_sage() # optional - macaulay2
+            sage: macaulay2([1,2,3]).sage()    # optional - macaulay2
             [1, 2, 3]
 
             sage: m = matrix([[1,2],[3,4]])
-            sage: macaulay2(m).to_sage()       # optional - macaulay2
+            sage: macaulay2(m).sage()          # optional - macaulay2
             [1 2]
             [3 4]
 
-            sage: macaulay2(QQ['x,y']).to_sage()    # optional - macaulay2
+            sage: D = macaulay2('hashTable {4 => 1, 2 => 3}')  # optional - macaulay2
+            sage: D.pairs()                    # optional - macaulay2
+            {(4, 1), (2, 3)}
+            sage: D.sage() == {4: 1, 2: 3}    # optional - macaulay2
+            True
+
+            sage: macaulay2(QQ['x,y']).sage()       # optional - macaulay2
             Multivariate Polynomial Ring in x, y over Rational Field
-            sage: macaulay2(QQ['x']).to_sage()      # optional - macaulay2
+            sage: macaulay2(QQ['x']).sage()         # optional - macaulay2
             Univariate Polynomial Ring in x over Rational Field
-            sage: macaulay2(GF(7)['x,y']).to_sage() # optional - macaulay2
+            sage: macaulay2(GF(7)['x,y']).sage()    # optional - macaulay2
             Multivariate Polynomial Ring in x, y over Finite Field of size 7
 
-            sage: macaulay2(GF(7)).to_sage()       # optional - macaulay2
+            sage: macaulay2(GF(7)).sage()          # optional - macaulay2
             Finite Field of size 7
-            sage: macaulay2(GF(49, 'a')).to_sage() # optional - macaulay2
+            sage: macaulay2(GF(49, 'a')).sage()    # optional - macaulay2
             Finite Field in a of size 7^2
 
             sage: R.<x,y> = QQ[]
-            sage: macaulay2(x^2+y^2+1).to_sage()   # optional - macaulay2
+            sage: macaulay2(x^2+y^2+1).sage()      # optional - macaulay2
             x^2 + y^2 + 1
 
             sage: R = macaulay2("QQ[x,y]")         # optional - macaulay2
             sage: I = macaulay2("ideal (x,y)")     # optional - macaulay2
-            sage: I.to_sage()                      # optional - macaulay2
+            sage: I.sage()                         # optional - macaulay2
             Ideal (x, y) of Multivariate Polynomial Ring in x, y over Rational Field
 
             sage: macaulay2("x = symbol x")           # optional - macaulay2
             x
-            sage: macaulay2("QQ[x_0..x_2]").to_sage() # optional - macaulay2
-            Multivariate Polynomial Ring in x_0, x_1, x_2 over Rational Field
+            sage: macaulay2("QQ[x_0..x_25]").sage()    # optional - macaulay2
+            Multivariate Polynomial Ring in x_0, x_1,..., x_25 over Rational Field
 
             sage: X = R/I       # optional - macaulay2
-            sage: X.to_sage()   # optional - macaulay2
+            sage: X.sage()      # optional - macaulay2
             Quotient of Multivariate Polynomial Ring in x, y over Rational Field by the ideal (x, y)
 
             sage: R = macaulay2("QQ^2")  # optional - macaulay2
-            sage: R.to_sage()            # optional - macaulay2
+            sage: R.sage()               # optional - macaulay2
             Vector space of dimension 2 over Rational Field
 
             sage: m = macaulay2('"hello"')  # optional - macaulay2
-            sage: m.to_sage()               # optional - macaulay2
+            sage: m.sage()                  # optional - macaulay2
             'hello'
 
         """
@@ -1072,15 +1284,17 @@ class Macaulay2Element(ExtraTabCompletion, ExpectElement):
 
         if cls_cls_str == "Type":
             if cls_str == "List":
-                return [entry.to_sage() for entry in self]
+                return [entry._sage_() for entry in self]
             elif cls_str == "Matrix":
                 from sage.matrix.all import matrix
-                base_ring = self.ring().to_sage()
-                entries = self.entries().to_sage()
+                base_ring = self.ring()._sage_()
+                entries = self.entries()._sage_()
                 return matrix(base_ring, entries)
+            elif cls_str == 'HashTable':
+                return {x._sage_(): y._sage_() for (x, y) in self.pairs()}
             elif cls_str == "Ideal":
-                parent = self.ring().to_sage()
-                gens = self.gens().entries().flatten().to_sage()
+                parent = self.ring()._sage_()
+                gens = self.gens().entries().flatten()._sage_()
                 return parent.ideal(*gens)
             elif cls_str == "QuotientRing":
                 #Handle the ZZ/n case
@@ -1093,21 +1307,21 @@ class Macaulay2Element(ExtraTabCompletion, ExpectElement):
                     #coming from Macaulay 2
                     return GF(ZZ(n))
 
-                ambient = self.ambient().to_sage()
-                ideal = self.ideal().to_sage()
+                ambient = self.ambient()._sage_()
+                ideal = self.ideal()._sage_()
                 return ambient.quotient(ideal)
             elif cls_str == "PolynomialRing":
                 from sage.rings.all import PolynomialRing
                 from sage.rings.polynomial.term_order import inv_macaulay2_name_mapping
 
                 #Get the base ring
-                base_ring = self.coefficientRing().to_sage()
+                base_ring = self.coefficientRing()._sage_()
 
                 #Get a string list of generators
                 gens = str(self.gens().toString())[1:-1]
 
                 # Check that we are dealing with default degrees, i.e. 1's.
-                if self.degrees().any("x -> x != {1}").to_sage():
+                if self.degrees().any("x -> x != {1}")._sage_():
                     raise ValueError("cannot convert Macaulay2 polynomial ring with non-default degrees to Sage")
                 #Handle the term order
                 external_string = self.external_string()
@@ -1140,9 +1354,9 @@ class Macaulay2Element(ExtraTabCompletion, ExpectElement):
                 return str(repr_str)
             elif cls_str == "Module":
                 from sage.modules.all import FreeModule
-                if self.isFreeModule().to_sage():
-                    ring = self.ring().to_sage()
-                    rank = self.rank().to_sage()
+                if self.isFreeModule()._sage_():
+                    ring = self.ring()._sage_()
+                    rank = self.rank()._sage_()
                     return FreeModule(ring, rank)
         else:
             #Handle the integers and rationals separately
@@ -1157,7 +1371,7 @@ class Macaulay2Element(ExtraTabCompletion, ExpectElement):
                 return QQ(repr_str)
 
             m2_parent = self.cls()
-            parent = m2_parent.to_sage()
+            parent = m2_parent._sage_()
 
             if cls_cls_str == "PolynomialRing":
                 from sage.misc.sage_eval import sage_eval
@@ -1170,6 +1384,9 @@ class Macaulay2Element(ExtraTabCompletion, ExpectElement):
         except Exception:
             raise NotImplementedError("cannot convert %s to a Sage object"%repr_str)
 
+    from sage.misc.superseded import deprecated_function_alias
+    to_sage = deprecated_function_alias(27848, ExpectElement.sage)
+
 
 @instancedoc
 class Macaulay2Function(ExpectFunction):
@@ -1178,7 +1395,7 @@ class Macaulay2Function(ExpectFunction):
         EXAMPLES::
 
             sage: print(macaulay2.load.__doc__)  # optional - macaulay2
-            load ...
+            load...
             ****...
             ...
               * "input" -- read Macaulay2 commands and echo
@@ -1201,7 +1418,7 @@ class Macaulay2Function(ExpectFunction):
         E.expect(self._parent._prompt)
         s = E.before
         self._parent.eval("2+2")
-        return s
+        return bytes_to_str(s)
 
 def is_Macaulay2Element(x):
     """
