@@ -61,7 +61,6 @@ from . import matrix_mpolynomial_dense
 from sage.misc.superseded import deprecation
 import sage.structure.coerce
 from sage.structure.parent import Parent
-from sage.structure.element import is_Matrix
 from sage.structure.unique_representation import UniqueRepresentation
 import sage.rings.integer as integer
 import sage.rings.number_field.all
@@ -921,8 +920,10 @@ class MatrixSpace(UniqueRepresentation, Parent):
             sage: V.get_action(ZZ, operator.mul, self_on_left=False)
             Left scalar multiplication by Integer Ring on Full MatrixSpace of 2 by 3 dense matrices over Rational Field
         """
-        if op is operator.mul:
-            try:
+        try:
+            from sage.schemes.generic.algebraic_scheme import AlgebraicScheme
+            from sage.schemes.generic.homset import SchemeHomset_generic
+            if op is operator.mul:
                 from . import action as matrix_action
                 if self_on_left:
                     if is_MatrixSpace(S):
@@ -930,6 +931,8 @@ class MatrixSpace(UniqueRepresentation, Parent):
                         return matrix_action.MatrixMatrixAction(self, S)
                     elif sage.modules.free_module.is_FreeModule(S):
                         return matrix_action.MatrixVectorAction(self, S)
+                    elif isinstance(S, SchemeHomset_generic):
+                        return matrix_action.MatrixPolymapAction(self, S)
                     else:
                         # action of base ring
                         return sage.structure.coerce.RightModuleAction(S, self)
@@ -939,11 +942,13 @@ class MatrixSpace(UniqueRepresentation, Parent):
                         return matrix_action.MatrixMatrixAction(S, self)
                     elif sage.modules.free_module.is_FreeModule(S):
                         return matrix_action.VectorMatrixAction(self, S)
+                    elif isinstance(S, SchemeHomset_generic):
+                        return matrix_action.PolymapMatrixAction(self, S)
                     else:
                         # action of base ring
                         return sage.structure.coerce.LeftModuleAction(S, self)
-            except TypeError:
-                return None
+        except TypeError:
+            return None
 
     def _coerce_map_from_(self, S):
         """
@@ -2092,9 +2097,9 @@ class MatrixSpace(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - ``*args``, ``**kwds`` - Parameters that can be forwarded to the 
+        - ``*args``, ``**kwds`` - Parameters that can be forwarded to the
           ``random_element`` method
-        
+
         OUTPUT:
 
         - Random non-zero matrix
