@@ -23,14 +23,11 @@ from six import iteritems
 
 import os
 import sys
-import re
 import shutil
 import pkgconfig
 
-from textwrap import dedent
-
-from sage.env import (SAGE_LOCAL, SAGE_SRC, cython_aliases,
-        sage_include_directories)
+from sage.env import (SAGE_LOCAL, cython_aliases,
+                      sage_include_directories)
 from sage.misc.misc import SPYX_TMP, sage_makedirs
 from .temporary_file import tmp_filename
 from sage.repl.user_globals import get_globals
