@@ -101,14 +101,12 @@ Check that Cython source code appears in tracebacks::
 #*****************************************************************************
 
 
-import os
 import re
-from sage.repl.preparse import preparse
-from sage.repl.prompts import SagePrompts, InterfacePrompts
+from sage.repl.preparse import preparse, containing_block
+from sage.repl.prompts import InterfacePrompts
 
 from traitlets import Bool, Type
 
-from sage.env import SAGE_LOCAL
 from sage.repl.configuration import sage_ipython_config, SAGE_EXTENSION
 
 def embedded():
@@ -360,10 +358,9 @@ class SageTestShell(SageShellOverride, TerminalInteractiveShell):
             True
             sage: shell.quit()
         """
-        rc = super(SageTestShell, self).run_cell(*args, **kwds)
+        super(SageTestShell, self).run_cell(*args, **kwds)
 
 
-    
 ###################################################################
 # Transformers used in the SageInputSplitter
 ###################################################################
@@ -475,7 +472,7 @@ class InterfaceShellTransformer(PrefilterTransformer):
 
         .. SEEALSO:: :func:`interface_shell_embed`
 
-        EXAMPLES::
+        TESTS::
 
             sage: from sage.repl.interpreter import interface_shell_embed
             sage: shell = interface_shell_embed(maxima)
@@ -483,11 +480,12 @@ class InterfaceShellTransformer(PrefilterTransformer):
             sage: ift.temporary_objects
             set()
             sage: ift._sage_import_re.findall('sage(a) + maxima(b)')
-            ['a', 'b']
+            ['sage(', 'maxima(']
         """
         super(InterfaceShellTransformer, self).__init__(*args, **kwds)
         self.temporary_objects = set()
-        self._sage_import_re = re.compile(r'(?:sage|%s)\((.*?)\)'%self.shell.interface.name())
+        self._sage_import_re = re.compile(r'(?:sage|%s)\('
+                                          % self.shell.interface.name())
 
     def preparse_imports_from_sage(self, line):
         """
@@ -501,12 +499,6 @@ class InterfaceShellTransformer(PrefilterTransformer):
         :param line: the line to transform
         :type line: string
 
-        .. warning::
-
-            This does not parse nested parentheses correctly.  Thus,
-            lines like ``sage(a.foo())`` will not work correctly.
-            This can't be done in generality with regular expressions.
-
         EXAMPLES::
 
             sage: from sage.repl.interpreter import interface_shell_embed, InterfaceShellTransformer
@@ -521,13 +513,33 @@ class InterfaceShellTransformer(PrefilterTransformer):
             '2 +  sage4 '
             sage: ift.preparse_imports_from_sage('2 + gap(a)')
             '2 + gap(a)'
+
+        Since :trac:`28439`, this also works with more complicated expressions
+        containing nested parentheses::
+
+            sage: shell = interface_shell_embed(gap)
+            sage: shell.user_ns = locals()
+            sage: ift = InterfaceShellTransformer(shell=shell, config=shell.config, prefilter_manager=shell.prefilter_manager)
+            sage: line = '2 + sage((1+2)*gap(-(5-3)^2).sage()) - gap(1+(2-1))'
+            sage: line = ift.preparse_imports_from_sage(line)
+            sage: gap.eval(line)
+            '-12'
         """
-        for sage_code in self._sage_import_re.findall(line):
-            expr = preparse(sage_code)
+        new_line = []
+        pos = 0
+        while True:
+            m = self._sage_import_re.search(line, pos)
+            if not m:
+                new_line.append(line[pos:])
+                break
+            expr_start, expr_end = containing_block(line, m.end() - 1,
+                                                    delimiters=['()'])
+            expr = preparse(line[expr_start+1:expr_end-1])
             result = self.shell.interface(eval(expr, self.shell.user_ns))
             self.temporary_objects.add(result)
-            line = self._sage_import_re.sub(' ' + result.name() + ' ', line, 1)
-        return line
+            new_line += [line[pos:m.start()], result.name()]
+            pos = expr_end
+        return ' '.join(new_line)
 
     def transform(self, line, continue_prompt):
         r'''
@@ -545,16 +557,31 @@ class InterfaceShellTransformer(PrefilterTransformer):
             sage: shell = interface_shell_embed(maxima)
             sage: ift = InterfaceShellTransformer(shell=shell, config=shell.config, prefilter_manager=shell.prefilter_manager)
             sage: ift.transform('2+2', False)   # note: output contains triple quotation marks
-            'sage.misc.all.logstr("""4""")'
+            'sage.misc.all.logstr(r"""4""")'
             sage: ift.shell.ex('a = 4')
             sage: ift.transform(r'sage(a)+4', False)
-            'sage.misc.all.logstr("""8""")'
+            'sage.misc.all.logstr(r"""8""")'
             sage: ift.temporary_objects
             set()
             sage: shell = interface_shell_embed(gap)
             sage: ift = InterfaceShellTransformer(shell=shell, config=shell.config, prefilter_manager=shell.prefilter_manager)
             sage: ift.transform('2+2', False)
-            'sage.misc.all.logstr("""4""")'
+            'sage.misc.all.logstr(r"""4""")'
+
+        TESTS:
+
+        Check that whitespace is not stripped and that special characters are
+        escaped (:trac:`28439`)::
+
+            sage: shell = interface_shell_embed(gap)
+            sage: ift = InterfaceShellTransformer(shell=shell, config=shell.config, prefilter_manager=shell.prefilter_manager)
+            sage: ift.transform(r'Print("  -\n\\\\-  ");', False)
+            'sage.misc.all.logstr(r"""  -\n\\\\-""")'
+
+            sage: shell = interface_shell_embed(macaulay2)  # optional - macaulay2
+            sage: ift = InterfaceShellTransformer(shell=shell, config=shell.config, prefilter_manager=shell.prefilter_manager) # optional - macaulay2
+            sage: ift.transform('net(ZZ^2)', False)  # optional - macaulay2
+            'sage.misc.all.logstr(r"""  2\nZZ""")'
         '''
         line = self.preparse_imports_from_sage(line)
 
@@ -564,7 +591,9 @@ class InterfaceShellTransformer(PrefilterTransformer):
             # Once we've evaluated the lines, we can clear the
             # temporary objects
             self.temporary_objects = set()
-        return 'sage.misc.all.logstr("""%s""")'%t.strip()
+        # We do not strip whitespace from t here as the individual interface is
+        # responsible for that
+        return 'sage.misc.all.logstr(r"""%s""")' % t
 
 def interface_shell_embed(interface):
     """
