@@ -618,7 +618,7 @@ class AsymptoticExpansionGenerators(SageObject):
 
         - ``zeta`` -- (default: `1`) the location of the singularity.
 
-        - ``alpha`` -- (default: `0`) the pole order of the singularty.
+        - ``alpha`` -- (default: `0`) the pole order of the singularity.
 
         - ``beta`` -- (default: `0`) the order of the logarithmic singularity.
 
@@ -1185,7 +1185,7 @@ class AsymptoticExpansionGenerators(SageObject):
         for k in srange(2, precision-1):
             coef = z_expansion.monomial_coefficient((1/Z)**((k+1) * one_half))
             current_var = SR('d{k}'.format(k=k))
-            solution_dict[current_var] = coef.subs(solution_dict).solve(current_var)[0].rhs()
+            solution_dict[current_var] = coef.subs(solution_dict).simplify_rational().solve(current_var)[0].rhs()
 
         return A(tau) + ansatz(prec=precision-1).map_coefficients(lambda term: term.subs(solution_dict).simplify_rational())
 
