@@ -1443,7 +1443,7 @@ class DifferentialPrecisionGeneric(SageObject):
             for (event, index, tme) in self._history:
                 if event == 'partial reduce' or event == 'full reduce':
                     if separate_reduce:
-                        if total_time > 0:
+                        if status:
                             hist.append(self._format_history(total_time, status, timings))
                         if event == 'partial reduce': code = 'r'
                         else: code = 'R'
@@ -1455,7 +1455,7 @@ class DifferentialPrecisionGeneric(SageObject):
                         total_time += tme
                     continue
                 if not compact or event != oldevent:
-                    if total_time > 0:
+                    if status:
                         hist.append(self._format_history(total_time, status, timings))
                     total_time = 0
                     oldevent = event
@@ -1469,7 +1469,7 @@ class DifferentialPrecisionGeneric(SageObject):
                     status[index] = '~'
                 elif event == 'del':
                     del status[index]
-            if total_time > 0 or oldevent == '':
+            if status or oldevent == '':
                 hist.append(self._format_history(total_time, status, timings))
             return '\n'.join(hist)
         else:
@@ -1820,7 +1820,6 @@ class PrecisionLattice(UniqueRepresentation, DifferentialPrecisionGeneric):
             sage: prec.precision_lattice()
             []
         """
-        p = self._p
         n = len(self._elements)
 
         # We mark new collected elements for deletion
@@ -2417,8 +2416,6 @@ class PrecisionModule(UniqueRepresentation, DifferentialPrecisionGeneric):
             sage: prec.precision_lattice()
             []
         """
-        p = self._p
-
         # We mark new collected elements for deletion
         # The list self._collected_references can be updated while
         # the loop runs.
@@ -2442,7 +2439,8 @@ class PrecisionModule(UniqueRepresentation, DifferentialPrecisionGeneric):
                 # if the column is not a pivot, we erase it without delay
                 # (btw, is it a good idea?)
                 del self._elements[index]
-                self._marked_for_deletion = [ i if i < index else i-1 for i in self._marked_for_deletion ]
+                self._marked_for_deletion = [i if i < index else i - 1
+                                             for i in self._marked_for_deletion]
                 if self._history is not None:
                     self._history.append(('del', index, walltime(tme)))
         del self._collected_references[:count]
