@@ -743,6 +743,180 @@ class RationalField(Singleton, number_field_base.NumberField):
         from sage.rings.finite_rings.residue_field import ResidueField
         return ResidueField(ZZ.ideal(p), check=check)
 
+    def hilbert_symbol_negative_at_S(self, S, b, check=True):
+        r"""
+        Returns an integer that has a negative Hilbert symbol with respect
+        to a given rational number and a given set of primes (or places).
+
+        The function is algorithm 3.4.1 in [Kir2016]_. It finds an integer `a`
+        that has negative Hilbert symbol with respect to a given rational number
+        exactly at a given set of primes (or places).
+
+        INPUT:
+
+        - ``S`` -- a list of rational primes, the infinite place as real
+          embedding of `\QQ` or as -1
+        - ``b`` -- a non-zero rational number which is a non-square locally
+          at every prime in ``S``.
+        - ``check`` -- ``bool`` (default:``True``) perform additional checks on
+          input and confirm the output.
+
+        OUTPUT:
+
+        - An integer `a` that has negative Hilbert symbol `(a,b)_p` for
+          every place `p` in `S` and no other place.
+
+        EXAMPLES::
+
+            sage: QQ.hilbert_symbol_negative_at_S([-1,5,3,2,7,11,13,23], -10/7)
+            -9867
+            sage: QQ.hilbert_symbol_negative_at_S([3, 5, QQ.places()[0], 11], -15)
+            -33
+            sage: QQ.hilbert_symbol_negative_at_S([3, 5], 2)
+            15
+
+        TESTS::
+
+            sage: QQ.hilbert_symbol_negative_at_S(5/2, -2)
+            Traceback (most recent call last):
+            ...
+            TypeError: first argument must be a list or integer
+
+        ::
+
+            sage: QQ.hilbert_symbol_negative_at_S([1, 3], 0)
+            Traceback (most recent call last):
+            ...
+            ValueError: second argument must be nonzero
+
+        ::
+
+            sage: QQ.hilbert_symbol_negative_at_S([-1, 3, 5], 2)
+            Traceback (most recent call last):
+            ...
+            ValueError: list should be of even cardinality
+
+        ::
+
+            sage: QQ.hilbert_symbol_negative_at_S([1, 3], 2)
+            Traceback (most recent call last):
+            ...
+            ValueError: all entries in list must be prime or -1 for
+            infinite place
+
+        ::
+
+            sage: QQ.hilbert_symbol_negative_at_S([5, 7], 2)
+            Traceback (most recent call last):
+            ...
+            ValueError: second argument must be a nonsquare with
+            respect to every finite prime in the list
+
+        ::
+
+            sage: QQ.hilbert_symbol_negative_at_S([1, 3], sqrt(2))
+            Traceback (most recent call last):
+            ...
+            TypeError: second argument must be a rational number
+
+        ::
+
+            sage: QQ.hilbert_symbol_negative_at_S([-1, 3], 2)
+            Traceback (most recent call last):
+            ...
+            ValueError: if the infinite place is in the list, the second
+            argument must be negative
+
+        AUTHORS:
+
+        - Simon Brandhorst, Juanita Duque, Anna Haensch, Manami Roy, Sandi Rudzinski (10-24-2017)
+
+        """
+        from sage.rings.finite_rings.finite_field_constructor import FiniteField as GF
+        from sage.rings.padics.factory import Qp
+        from sage.modules.free_module import VectorSpace
+        from sage.matrix.constructor import matrix
+        from sage.sets.primes import Primes
+        from sage.arith.misc import hilbert_symbol, is_prime
+
+        # input checks
+        if not type(S) is list:
+            raise TypeError("first argument must be a list or integer")
+        # -1 is used for the infinite place
+        infty = -1
+        for i in range(len(S)):
+            if S[i] == self.places()[0]:
+                S[i] = -1
+        if not b in self:
+            raise TypeError("second argument must be a rational number")
+        b = self(b)
+        if b == 0:
+            raise ValueError("second argument must be nonzero")
+        if len(S) % 2 != 0:
+            raise ValueError("list should be of even cardinality")
+        for p in S:
+            if p != infty:
+                if check and not is_prime(p):
+                    raise ValueError("all entries in list must be prime"
+                                    " or -1 for infinite place")
+                R = Qp(p)
+                if R(b).is_square():
+                    raise ValueError("second argument must be a nonsquare with"
+                                     " respect to every finite prime in the list")
+            elif b > 0:
+                raise ValueError("if the infinite place is in the list, "
+                                 "the second argument must be negative")
+        # L is the list of primes that we need to consider, b must have
+        # nonzero valuation for each prime in L, this is the set S'
+        # in Kirschmer's algorithm
+        L = []
+        L = [p[0] for p in b.factor() if p[0] not in S]
+        # We must also consider 2 to be in L
+        if 2 not in L and 2 not in S:
+            L.append(2)
+        # This adds the infinite place to L
+        if b < 0 and infty not in S:
+            L.append(infty)
+
+        P = S + L
+        # This constructs the vector v in the algorithm. This is the vector
+        # that we are searching for. It represents the case when the Hilbert
+        # symbol is negative for all primes in S and positive
+        # at all primes in S'
+        V = VectorSpace(GF(2), len(P))
+        v = V([1]*len(S) + [0]*len(L))
+
+        # Compute the map phi of Hilbert symbols at all the primes
+        # in S and S'
+        # For technical reasons, a Hilbert symbol of -1 is
+        # respresented as 1 and a Hilbert symbol of 1
+        # is represented as 0
+        def phi(x):
+            v = [(1-hilbert_symbol(x, b, p))//2 for p in P]
+            return V(v)
+
+
+        M = matrix(GF(2), [phi(p) for p in P+[-1]])
+        # We search through all the primes
+        for q in Primes():
+            # Only look at this prime if it is not in our list
+            if q in P:
+                continue
+
+            # The algorithm terminates when the vector v is in the
+            # subspace of V generated by the image of the phi map
+            # on the set of generators
+            w = phi(q)
+            W = M.stack(matrix(w))
+            if v in W.row_space():
+                break
+        Pq = P + [-1] + [q]
+        l = W.solve_left(v)
+        a = self.prod([Pq[i]**ZZ(l[i]) for i in range(l.degree())])
+        if check:
+            assert phi(a) == v, "oops"
+        return  a
+
     def gens(self):
         r"""
         Return a tuple of generators of `\QQ` which is only ``(1,)``.
