@@ -713,6 +713,108 @@ class SchemeMorphism_polynomial_affine_space(SchemeMorphism_polynomial):
         self.__jacobian = jacobian(list(self),self.domain().ambient_space().gens())
         return self.__jacobian
 
+    def _matrix_times_polymap_(self, mat, h):
+        """
+        Multiplies the morphism on the left by a matrix ``mat``.
+
+        INPUT:
+
+        - ``mat`` -- a matrix
+
+        OUTPUT: a scheme morphism given by ``self*mat``
+
+        EXAMPLES::
+
+            sage: A.<x> = AffineSpace(ZZ, 1)
+            sage: H = Hom(A, A)
+            sage: f = H([x^2 + 1])
+            sage: matrix([[1,2], [0,1]]) * f
+            Scheme endomorphism of Affine Space of dimension 1 over Integer Ring
+              Defn: Defined on coordinates by sending (x) to
+                    (x^2 + 3)
+
+        ::
+
+            sage: A1 = AffineSpace(ZZ,1)
+            sage: A2 = AffineSpace(ZZ,2)
+            sage: H = Hom(A1, A2)
+            sage: f = H([x^2+1,x^2-1])
+            sage: matrix([[1,2,3], [0,1,2], [0,0,1]]) * f
+            Scheme morphism:
+              From: Affine Space of dimension 1 over Integer Ring
+              To:   Affine Space of dimension 2 over Integer Ring
+              Defn: Defined on coordinates by sending (x) to
+                    (3*x^2 + 2, x^2 + 1)
+        """
+        if not mat.is_square():
+            raise TypeError("matrix must be square")
+        if mat.ncols() != self.codomain().ngens() + 1:
+            raise TypeError("the size of the matrix must be n + 1, where n is the dimension of the codomain")
+        if self.is_endomorphism():
+            d = self.domain().ngens()
+        else:
+            d = (self.domain().ngens(),self.codomain().ngens())
+        f = mat*self.homogenize(d)
+        return f.dehomogenize(d)
+
+    def _polymap_times_matrix_(self, mat, h):
+        """
+        Multiplies the morphism on the right by a matrix ``mat``.
+
+        INPUT:
+
+        - ``mat`` -- a matrix
+
+        OUTPUT: a scheme morphism given by ``mat*self``
+
+        EXAMPLES::
+
+            sage: A.<x> = AffineSpace(ZZ, 1)
+            sage: H = Hom(A, A)
+            sage: f = H([x^2 + 1])
+            sage: f * matrix([[1,2], [0,1]])
+            Scheme endomorphism of Affine Space of dimension 1 over Integer Ring
+              Defn: Defined on coordinates by sending (x) to
+                    (x^2 + 4*x + 5)
+
+        ::
+
+            sage: A1 = AffineSpace(ZZ,1)
+            sage: A2 = AffineSpace(ZZ,2)
+            sage: H = Hom(A1, A2)
+            sage: f = H([x^2+1,x^2-1])
+            sage: f * matrix([[1,2], [0,1]])
+            Scheme morphism:
+              From: Affine Space of dimension 1 over Integer Ring
+              To:   Affine Space of dimension 2 over Integer Ring
+              Defn: Defined on coordinates by sending (x) to
+                    (x^2 + 4*x + 5, x^2 + 4*x + 3)
+
+        ::
+
+            sage: P.<x, y> = AffineSpace(QQ, 2)
+            sage: P2.<u,v,w> = AffineSpace(QQ,3)
+            sage: H = Hom(P2, P)
+            sage: f = H([u^2 + v^2, w^2])
+            sage: m = matrix([[1,1,1], [1,0,1],[0,0,1]])
+            sage: m*f
+            Scheme morphism:
+              From: Affine Space of dimension 3 over Rational Field
+              To:   Affine Space of dimension 2 over Rational Field
+              Defn: Defined on coordinates by sending (u, v, w) to
+                    (u^2 + v^2 + w^2 + 1, u^2 + v^2 + 1)
+        """
+        if not mat.is_square():
+            raise TypeError("matrix must be square")
+        if mat.nrows() != self.domain().ngens() + 1:
+            raise TypeError("the size of the matrix must be n + 1, where n is the dimension of the domain")
+        if self.is_endomorphism():
+            d = self.domain().ngens()
+        else:
+            d = (self.domain().ngens(),self.codomain().ngens())
+        f = self.homogenize(d)*mat
+        return f.dehomogenize(d)
+
 class SchemeMorphism_polynomial_affine_space_field(SchemeMorphism_polynomial_affine_space):
 
     @cached_method
@@ -771,6 +873,138 @@ class SchemeMorphism_polynomial_affine_space_field(SchemeMorphism_polynomial_aff
 
         return(H(result))
 
+    def reduce_base_field(self):
+        """
+        Return this map defined over the field of definition of the coefficients.
+
+        The base field of the map could be strictly larger than
+        the field where all of the coefficients are defined. This function
+        reduces the base field to the minimal possible. This can be done when
+        the base ring is a number field, QQbar, a finite field, or algebraic
+        closure of a finite field.
+
+        OUTPUT: A scheme morphism.
+
+        EXAMPLES::
+
+            sage: K.<t> = GF(5^4)
+            sage: A.<x> = AffineSpace(K, 1)
+            sage: A2.<a,b> = AffineSpace(K, 2)
+            sage: H = End(A)
+            sage: H2 = Hom(A,A2)
+            sage: H3 = Hom(A2,A)
+            sage: f = H([x^2 + 2*(t^3 + t^2 + t + 3)])
+            sage: f.reduce_base_field()
+            Scheme endomorphism of Affine Space of dimension 1 over Finite Field in t2 of size 5^2
+              Defn: Defined on coordinates by sending (x) to
+                    (x^2 + (2*t2))
+            sage: f2 = H2([x^2 + 4, 2*x])
+            sage: f2.reduce_base_field()
+            Scheme morphism:
+              From: Affine Space of dimension 1 over Finite Field of size 5
+              To:   Affine Space of dimension 2 over Finite Field of size 5
+              Defn: Defined on coordinates by sending (x) to
+                    (x^2 - 1, 2*x)
+            sage: f3 = H3([a^2 + t*b])
+            sage: f3.reduce_base_field()
+            Scheme morphism:
+              From: Affine Space of dimension 2 over Finite Field in t of size 5^4
+              To:   Affine Space of dimension 1 over Finite Field in t of size 5^4
+              Defn: Defined on coordinates by sending (a, b) to
+                    (a^2 + (t)*b)
+
+        ::
+
+            sage: K.<v> = CyclotomicField(4)
+            sage: A.<x> = AffineSpace(K, 1)
+            sage: H = End(A)
+            sage: f = H([x^2 + v])
+            sage: g = f.reduce_base_field();g
+            Scheme endomorphism of Affine Space of dimension 1 over Cyclotomic Field of order 4 and degree 2
+              Defn: Defined on coordinates by sending (x) to
+                (x^2 + (v))
+            sage: g.base_ring() is K
+            True
+
+        ::
+
+            sage: A.<x> = AffineSpace(QQbar, 1)
+            sage: H = End(A)
+            sage: f = H([(QQbar(sqrt(2))*x^2 + 1/QQbar(sqrt(3))) / (5*x)])
+            sage: f.reduce_base_field()
+            Scheme endomorphism of Affine Space of dimension 1 over Number Field in a with defining polynomial y^4 - 4*y^2 + 1 with a = 1.931851652578137?
+              Defn: Defined on coordinates by sending (x) to
+                    (((a^3 - 3*a)*x^2 + (1/3*a^2 - 2/3))/(5*x))
+
+        ::
+
+            sage: R.<x> = PolynomialRing(QQ)
+            sage: A.<x> =AffineSpace(QQbar,1)
+            sage: H = End(A)
+            sage: f = H([QQbar(3^(1/3))*x^2 + QQbar(sqrt(-2))])
+            sage: f.reduce_base_field()
+            Scheme endomorphism of Affine Space of dimension 1 over Number
+            Field in a with defining polynomial y^6 + 6*y^4 - 6*y^3 + 12*y^2 + 36*y + 17
+            with a = 1.442249570307409? + 1.414213562373095?*I
+              Defn: Defined on coordinates by sending (x) to
+                    ((-48/269*a^5 + 27/269*a^4 - 320/269*a^3 + 468/269*a^2 - 772/269*a
+                    - 1092/269)*x^2 + (48/269*a^5 - 27/269*a^4 + 320/269*a^3 - 468/269*a^2
+                    + 1041/269*a + 1092/269))
+
+        ::
+
+            sage: R.<x> = PolynomialRing(QQ)
+            sage: K.<a> = NumberField(x^3-x+1, embedding=(x^3+x+1).roots(ring=CC)[0][0])
+            sage: A.<x> = AffineSpace(K,1)
+            sage: A2.<u,v> = AffineSpace(K,2)
+            sage: H = Hom(A, A2)
+            sage: f = H([x^2 + a*x + 3, 5*x])
+            sage: f.reduce_base_field()
+            Scheme morphism:
+                  From: Affine Space of dimension 1 over Number Field in a with
+                  defining polynomial x^3 - x + 1 with a = -1.324717957244746?
+                  To:   Affine Space of dimension 2 over Number Field in a with
+                  defining polynomial x^3 - x + 1 with a = -1.324717957244746?
+                  Defn: Defined on coordinates by sending (x) to
+                        (x^2 + (a)*x + 3, 5*x)
+
+        ::
+
+            sage: K.<v> = QuadraticField(2)
+            sage: A.<x> =AffineSpace(K,1)
+            sage: H = End(A)
+            sage: f = H([3*x^2 + x + 1])
+            sage: f.reduce_base_field()
+            Scheme endomorphism of Affine Space of dimension 1 over Rational Field
+              Defn: Defined on coordinates by sending (x) to
+                    (3*x^2 + x + 1)
+
+        ::
+
+            sage: K.<t> = GF(5^6)
+            sage: A.<x> = AffineSpace(K, 1)
+            sage: H = End(A)
+            sage: f = H([x^2 + x*(t^3 + 2*t^2 + 4*t) + (t^5 + 3*t^4 + t^2 + 4*t)])
+            sage: f.reduce_base_field()
+            Scheme endomorphism of Affine Space of dimension 1 over Finite Field in t of size 5^6
+              Defn: Defined on coordinates by sending (x) to
+                    (x^2 + (t^3 + 2*t^2 - t)*x + (t^5 - 2*t^4 + t^2 - t))
+        """
+        g = self.homogenize(0).reduce_base_field().dehomogenize(0)
+        from sage.schemes.affine.affine_space import AffineSpace
+        new_domain = AffineSpace(g.domain().base_ring(),
+                                 self.domain().dimension_relative(),
+                                 self.domain().variable_names())
+        new_codomain = AffineSpace(g.codomain().base_ring(),
+                                   self.codomain().dimension_relative(),
+                                   self.codomain().variable_names())
+        R = new_domain.coordinate_ring()
+        H = Hom(new_domain, new_codomain)
+        if isinstance(g[0], FractionFieldElement):
+            return H([R(G.numerator())/R(G.denominator()) for G in g])
+        return H([R(G) for G in g])
+
+
 class SchemeMorphism_polynomial_affine_space_finite_field(SchemeMorphism_polynomial_affine_space_field):
 
     def _fast_eval(self, x):
