@@ -2,30 +2,14 @@ r"""
 Canonical heights for elliptic curves over number fields
 
 Also, rigorous lower bounds for the canonical height of non-torsion
-points, implementing the algorithms in [CS]_ (over `\QQ`) and [TT]_,
-which also refer to [CPS]_.
+points, implementing the algorithms in [CS2006]_ (over `\QQ`) and [Tho2010]_,
+which also refer to [CPS2006]_.
 
 AUTHORS:
 
 - Robert Bradshaw (2010): initial version
 
 - John Cremona (2014): added many docstrings and doctests
-
-REFERENCES:
-
-.. [CS] \J.E.Cremona, and S. Siksek, Computing a Lower Bound for the
-   Canonical Height on Elliptic Curves over `\QQ`, ANTS VII
-   Proceedings: F.Hess, S.Pauli and M.Pohst (eds.), ANTS VII, Lecture
-   Notes in Computer Science 4076 (2006), pages 275-286.
-
-.. [TT] \T. Thongjunthug, Computing a lower bound for the canonical
-   height on elliptic curves over number fields, Math. Comp. 79
-   (2010), pages 2431-2449.
-
-.. [CPS] \J.E. Cremona, M. Prickett and S. Siksek, Height Difference
-   Bounds For Elliptic Curves over Number Fields, Journal of Number
-   Theory 116(1) (2006), pages 42-68.
-
 """
 ##############################################################################
 #       Copyright (C) 2010 Robert Bradshaw <robertwb@math.washington.edu>
@@ -796,7 +780,7 @@ class EllipticCurveCanonicalHeight:
             sage: K.<i>=QuadraticField(-1)
             sage: E = EllipticCurve([0,i,0,i,i])
             sage: EllipticCurveCanonicalHeight(E)
-            EllipticCurveCanonicalHeight object associated to Elliptic Curve defined by y^2 = x^3 + i*x^2 + i*x + i over Number Field in i with defining polynomial x^2 + 1
+            EllipticCurveCanonicalHeight object associated to Elliptic Curve defined by y^2 = x^3 + i*x^2 + i*x + i over Number Field in i with defining polynomial x^2 + 1 with i = 1*I
 
         TESTS:
 
@@ -891,7 +875,7 @@ class EllipticCurveCanonicalHeight:
             sage: E = EllipticCurve(K, [0,0,0,1,-27])
             sage: H = E.height_function()
             sage: H.base_field()
-            Number Field in i with defining polynomial x^2 + 1
+            Number Field in i with defining polynomial x^2 + 1 with i = 1*I
             sage: H((1,5*i))
             1.22257115164148
         """
@@ -908,13 +892,13 @@ class EllipticCurveCanonicalHeight:
 
         OUTPUT:
 
-        The constant `\alpha_v`.  In the notation of [CPS]_ (2006) and
-        [TT]_ (section 3.2), `\alpha_v^3=\epsilon_v`.  The result is
+        The constant `\alpha_v`.  In the notation of [CPS2006]_ and
+        [Tho2010]_ (section 3.2), `\alpha_v^3=\epsilon_v`.  The result is
         cached since it only depends on the curve.
 
         EXAMPLES:
 
-        Example 1 from [CPS]_ (2006)::
+        Example 1 from [CPS2006]_::
 
             sage: K.<i>=QuadraticField(-1)
             sage: E = EllipticCurve([0,0,0,1+5*i,3+i])
@@ -923,7 +907,7 @@ class EllipticCurveCanonicalHeight:
             sage: alpha
             1.12272013439355
 
-        Compare with `\log(\epsilon_v)=0.344562...` in [CPS]_::
+        Compare with `\log(\epsilon_v)=0.344562...` in [CPS2006]_::
 
             sage: 3*alpha.log()
             0.347263296676126
@@ -1033,7 +1017,7 @@ class EllipticCurveCanonicalHeight:
 
         OUTPUT:
 
-        The value `D_E(n)` as defined in [TT]_, section 4.
+        The value `D_E(n)` as defined in [Tho2010]_, section 4.
 
         EXAMPLES::
 
@@ -1059,7 +1043,7 @@ class EllipticCurveCanonicalHeight:
 
         OUTPUT:
 
-        The norm of the ideal `M_E` as defined in [TT]_, section 3.1.
+        The norm of the ideal `M_E` as defined in [Tho2010]_, section 3.1.
         This is `1` if `E` is a global minimal model, and in general
         measures the non-minimality of `E`.
 
@@ -1098,17 +1082,17 @@ class EllipticCurveCanonicalHeight:
 
         OUTPUT:
 
-        The real value `B_n(\mu)` as defined in [TT]_, section 5.
+        The real value `B_n(\mu)` as defined in [Tho2010]_, section 5.
 
         EXAMPLES:
 
-        Example 10.2 from [TT]_::
+        Example 10.2 from [Tho2010]_::
 
             sage: K.<i>=QuadraticField(-1)
             sage: E = EllipticCurve([0,1-i,i,-i,0])
             sage: H = E.height_function()
 
-        In [TT]_ the value is given as 0.772::
+        In [Tho2010]_ the value is given as 0.772::
 
             sage: RealField(12)( H.B(5, 0.01) )
             0.777
@@ -1203,7 +1187,7 @@ class EllipticCurveCanonicalHeight:
 
         OUTPUT:
 
-        The union of intervals `S^{(v)}(\xi_1,\xi_2)` defined in [TT]_
+        The union of intervals `S^{(v)}(\xi_1,\xi_2)` defined in [Tho2010]_
         section 6.1.
 
         EXAMPLES:
@@ -1251,7 +1235,7 @@ class EllipticCurveCanonicalHeight:
 
         OUTPUT:
 
-        The union of intervals `S_n^{(v)}(\xi_1,\xi_2)` defined in [TT]_
+        The union of intervals `S_n^{(v)}(\xi_1,\xi_2)` defined in [Tho2010]_
         (Lemma 6.1).
 
         EXAMPLES:
@@ -1299,7 +1283,7 @@ class EllipticCurveCanonicalHeight:
         empty or not.  When ``Bk`` is the list of `b=B_n(\mu)` for
         `n=1,2,3,\dots` for some `\mu>0` this means that all
         non-torsion points on `E` with everywhere good reduction have
-        canonical height strictly greater than `\mu`, by [TT]_,
+        canonical height strictly greater than `\mu`, by [Tho2010]_,
         Proposition 6.2.
 
         EXAMPLES:
@@ -1399,7 +1383,7 @@ class EllipticCurveCanonicalHeight:
             sage: H.wp_c(K.places()[0])
             2.66213425640096
         """
-        # Note that we normalise w1, w2 differently from [TT]_!
+        # Note that we normalise w1, w2 differently from [Tho2010]_!
         w2, w1 = self.E.period_lattice(v).normalised_basis()
         return max(abs(v(self.E.c4()/240)) ** 0.5,
                    abs(v(self.E.c6()/6048)) ** (1.0/3)) * abs(w1)**2
@@ -1668,11 +1652,11 @@ class EllipticCurveCanonicalHeight:
 
         True or False, according as the intersection of the unions of
         intervals `T_n^{(v)}(-b,b)` for `b` in the list ``Bk`` (see
-        [TT]_, section 7) is empty or not.  When ``Bk`` is the list of
+        [Tho2010]_, section 7) is empty or not.  When ``Bk`` is the list of
         `b=\sqrt{B_n(\mu)}` for `n=1,2,3,\dots` for some `\mu>0` this
         means that all non-torsion points on `E` with everywhere good
         reduction have canonical height strictly greater than `\mu`,
-        by [TT]_, Proposition 7.8.
+        by [Tho2010]_, Proposition 7.8.
 
         EXAMPLES::
 
@@ -1704,7 +1688,7 @@ class EllipticCurveCanonicalHeight:
         from sage.schemes.elliptic_curves.period_lattice_region import PeriodicRegion
 
         b2 = v(self.E.b2())
-        # Note that we normalise w1, w2 differently from [TT]_!
+        # Note that we normalise w1, w2 differently from [Tho2010]_!
         w2, w1 = self.E.period_lattice(v).normalised_basis()
         tau = w2/w1
         bounds = [RDF((B.sqrt() + abs(b2)/12) * abs(w1) ** 2) for B in Bk]
@@ -1833,7 +1817,7 @@ class EllipticCurveCanonicalHeight:
             []
         """
         # Compute the list of values `B_n(\mu)` for n in 1..N.  If any
-        # of these is 1 we can return True right away (see [TT]_,
+        # of these is 1 we can return True right away (see [Tho2010]_,
         # Proposition 5.1).
         Bk = []
         for n in ZZ.range(1, N + 1):
@@ -1881,14 +1865,14 @@ class EllipticCurveCanonicalHeight:
 
         EXAMPLES:
 
-        Example 1 from [CS]_ (where a lower bound of 1.9865 was
+        Example 1 from [CS2006]_ (where a lower bound of 1.9865 was
         given)::
 
             sage: E = EllipticCurve([1, 0, 1, 421152067, 105484554028056]) # 60490d1
             sage: E.height_function().min_gr(.0001, 5)
             1.98684388146518
 
-        Example 10.1 from [TT]_ (where a lower bound of 0.18 was
+        Example 10.1 from [Tho2010]_ (where a lower bound of 0.18 was
         given)::
 
             sage: K.<i> = QuadraticField(-1)
@@ -1897,7 +1881,7 @@ class EllipticCurveCanonicalHeight:
             sage: H.min_gr(0.1,4) # long time (8.1s)
             0.1621049443313762
 
-        Example 10.2 from [TT]_::
+        Example 10.2 from [Tho2010]_::
 
             sage: K.<i> = QuadraticField(-1)
             sage: E = EllipticCurve([0,1-i,i,-i,0])
@@ -1914,7 +1898,7 @@ class EllipticCurveCanonicalHeight:
             sage: P.height()
             0.0230242154471211
 
-        Example 10.3 from [TT]_ (where the same bound of 0.25 is
+        Example 10.3 from [Tho2010]_ (where the same bound of 0.25 is
         given)::
 
             sage: K.<a> = NumberField(x^3-2)
@@ -2002,14 +1986,14 @@ class EllipticCurveCanonicalHeight:
 
         EXAMPLES:
 
-        Example 1 from [CS]_ (where the same lower bound of 0.1126 was
+        Example 1 from [CS2006]_ (where the same lower bound of 0.1126 was
         given)::
 
             sage: E = EllipticCurve([1, 0, 1, 421152067, 105484554028056]) # 60490d1
             sage: E.height_function().min(.0001, 5)
             0.0011263287309893311
 
-        Example 10.1 from [TT]_ (where a lower bound of 0.18 was
+        Example 10.1 from [Tho2010]_ (where a lower bound of 0.18 was
         given)::
 
             sage: K.<i> = QuadraticField(-1)
@@ -2018,7 +2002,7 @@ class EllipticCurveCanonicalHeight:
             sage: H.min(0.1,4) # long time (8.1s)
             0.1621049443313762
 
-        Example 10.2 from [TT]_::
+        Example 10.2 from [Tho2010]_::
 
             sage: K.<i> = QuadraticField(-1)
             sage: E = EllipticCurve([0,1-i,i,-i,0])
@@ -2033,7 +2017,7 @@ class EllipticCurveCanonicalHeight:
             sage: P.height()
             0.0230242154471211
 
-        Example 10.3 from [TT]_ (where the same bound of 0.0625 is
+        Example 10.3 from [Tho2010]_ (where the same bound of 0.0625 is
         given)::
 
             sage: K.<a> = NumberField(x^3-2)
